'''OpenGL extension EXT.abgr

Overview (from the spec)
	
	EXT_abgr extends the list of host-memory color formats.  Specifically,
	it provides a reverse-order alternative to image format RGBA.  The ABGR
	component order matches the cpack Iris GL format on big-endian machines.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/abgr.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_abgr'
GL_ABGR_EXT = constant.Constant( 'GL_ABGR_EXT', 0x8000 )


def glInitAbgrEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
