'''OpenGL extension ARB.instanced_arrays

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/instanced_arrays.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_instanced_arrays'

glVertexAttribDivisor = platform.createExtensionFunction( 
	'glVertexAttribDivisor', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLuint,),
	doc = 'glVertexAttribDivisor( GLuint(index), GLuint(divisor) ) -> None',
	argNames = ('index', 'divisor',),
)


def glInitInstancedArraysARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
