'''OpenGL extension SGIX.tag_sample_buffer

Overview (from the spec)
	
	The extensions defines a special purpose fast multisample clear.
	This clear can be used with some restrictions as a significantly
	faster alternative to Clear(DEPTH_BUFFER_BIT).
	
	The extension is based on the RealityEngine architecture and will
	probably never be supported by any other architecture.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SGIX/tag_sample_buffer.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_tag_sample_buffer'

glTagSampleBufferSGIX = platform.createExtensionFunction( 
	'glTagSampleBufferSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(),
	doc = 'glTagSampleBufferSGIX(  ) -> None',
	argNames = (),
)


def glInitTagSampleBufferSGIX():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
