'''OpenGL extension ARB.fragment_program_shadow

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.fragment_program_shadow to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.fragment_program_shadow import *
### END AUTOGENERATED SECTION

# This extension is entirely within the fragment program functionality,
# it doesn't affect the function-level operations AFAICS.
