'''OpenGL extension NV.geometry_shader4

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/geometry_shader4.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_geometry_shader4'



def glInitGeometryShader4NV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
