'''OpenGL extension ARB.multitexture

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/multitexture.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_multitexture'
GL_TEXTURE0_ARB = constant.Constant( 'GL_TEXTURE0_ARB', 0x84C0 )
GL_TEXTURE1_ARB = constant.Constant( 'GL_TEXTURE1_ARB', 0x84C1 )
GL_TEXTURE2_ARB = constant.Constant( 'GL_TEXTURE2_ARB', 0x84C2 )
GL_TEXTURE3_ARB = constant.Constant( 'GL_TEXTURE3_ARB', 0x84C3 )
GL_TEXTURE4_ARB = constant.Constant( 'GL_TEXTURE4_ARB', 0x84C4 )
GL_TEXTURE5_ARB = constant.Constant( 'GL_TEXTURE5_ARB', 0x84C5 )
GL_TEXTURE6_ARB = constant.Constant( 'GL_TEXTURE6_ARB', 0x84C6 )
GL_TEXTURE7_ARB = constant.Constant( 'GL_TEXTURE7_ARB', 0x84C7 )
GL_TEXTURE8_ARB = constant.Constant( 'GL_TEXTURE8_ARB', 0x84C8 )
GL_TEXTURE9_ARB = constant.Constant( 'GL_TEXTURE9_ARB', 0x84C9 )
GL_TEXTURE10_ARB = constant.Constant( 'GL_TEXTURE10_ARB', 0x84CA )
GL_TEXTURE11_ARB = constant.Constant( 'GL_TEXTURE11_ARB', 0x84CB )
GL_TEXTURE12_ARB = constant.Constant( 'GL_TEXTURE12_ARB', 0x84CC )
GL_TEXTURE13_ARB = constant.Constant( 'GL_TEXTURE13_ARB', 0x84CD )
GL_TEXTURE14_ARB = constant.Constant( 'GL_TEXTURE14_ARB', 0x84CE )
GL_TEXTURE15_ARB = constant.Constant( 'GL_TEXTURE15_ARB', 0x84CF )
GL_TEXTURE16_ARB = constant.Constant( 'GL_TEXTURE16_ARB', 0x84D0 )
GL_TEXTURE17_ARB = constant.Constant( 'GL_TEXTURE17_ARB', 0x84D1 )
GL_TEXTURE18_ARB = constant.Constant( 'GL_TEXTURE18_ARB', 0x84D2 )
GL_TEXTURE19_ARB = constant.Constant( 'GL_TEXTURE19_ARB', 0x84D3 )
GL_TEXTURE20_ARB = constant.Constant( 'GL_TEXTURE20_ARB', 0x84D4 )
GL_TEXTURE21_ARB = constant.Constant( 'GL_TEXTURE21_ARB', 0x84D5 )
GL_TEXTURE22_ARB = constant.Constant( 'GL_TEXTURE22_ARB', 0x84D6 )
GL_TEXTURE23_ARB = constant.Constant( 'GL_TEXTURE23_ARB', 0x84D7 )
GL_TEXTURE24_ARB = constant.Constant( 'GL_TEXTURE24_ARB', 0x84D8 )
GL_TEXTURE25_ARB = constant.Constant( 'GL_TEXTURE25_ARB', 0x84D9 )
GL_TEXTURE26_ARB = constant.Constant( 'GL_TEXTURE26_ARB', 0x84DA )
GL_TEXTURE27_ARB = constant.Constant( 'GL_TEXTURE27_ARB', 0x84DB )
GL_TEXTURE28_ARB = constant.Constant( 'GL_TEXTURE28_ARB', 0x84DC )
GL_TEXTURE29_ARB = constant.Constant( 'GL_TEXTURE29_ARB', 0x84DD )
GL_TEXTURE30_ARB = constant.Constant( 'GL_TEXTURE30_ARB', 0x84DE )
GL_TEXTURE31_ARB = constant.Constant( 'GL_TEXTURE31_ARB', 0x84DF )
GL_ACTIVE_TEXTURE_ARB = constant.Constant( 'GL_ACTIVE_TEXTURE_ARB', 0x84E0 )
GL_CLIENT_ACTIVE_TEXTURE_ARB = constant.Constant( 'GL_CLIENT_ACTIVE_TEXTURE_ARB', 0x84E1 )
GL_MAX_TEXTURE_UNITS_ARB = constant.Constant( 'GL_MAX_TEXTURE_UNITS_ARB', 0x84E2 )
glActiveTextureARB = platform.createExtensionFunction( 
	'glActiveTextureARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glActiveTextureARB( GLenum(texture) ) -> None',
	argNames = ('texture',),
)

glClientActiveTextureARB = platform.createExtensionFunction( 
	'glClientActiveTextureARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glClientActiveTextureARB( GLenum(texture) ) -> None',
	argNames = ('texture',),
)

glMultiTexCoord1dARB = platform.createExtensionFunction( 
	'glMultiTexCoord1dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble,),
	doc = 'glMultiTexCoord1dARB( GLenum(target), GLdouble(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1dvARB = platform.createExtensionFunction( 
	'glMultiTexCoord1dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord1dvARB( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1fARB = platform.createExtensionFunction( 
	'glMultiTexCoord1fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat,),
	doc = 'glMultiTexCoord1fARB( GLenum(target), GLfloat(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1fvARB = platform.createExtensionFunction( 
	'glMultiTexCoord1fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord1fvARB( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1iARB = platform.createExtensionFunction( 
	'glMultiTexCoord1iARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint,),
	doc = 'glMultiTexCoord1iARB( GLenum(target), GLint(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1ivARB = platform.createExtensionFunction( 
	'glMultiTexCoord1ivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord1ivARB( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1sARB = platform.createExtensionFunction( 
	'glMultiTexCoord1sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort,),
	doc = 'glMultiTexCoord1sARB( GLenum(target), GLshort(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1svARB = platform.createExtensionFunction( 
	'glMultiTexCoord1svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord1svARB( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2dARB = platform.createExtensionFunction( 
	'glMultiTexCoord2dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord2dARB( GLenum(target), GLdouble(s), GLdouble(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2dvARB = platform.createExtensionFunction( 
	'glMultiTexCoord2dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord2dvARB( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2fARB = platform.createExtensionFunction( 
	'glMultiTexCoord2fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord2fARB( GLenum(target), GLfloat(s), GLfloat(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2fvARB = platform.createExtensionFunction( 
	'glMultiTexCoord2fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord2fvARB( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2iARB = platform.createExtensionFunction( 
	'glMultiTexCoord2iARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord2iARB( GLenum(target), GLint(s), GLint(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2ivARB = platform.createExtensionFunction( 
	'glMultiTexCoord2ivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord2ivARB( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2sARB = platform.createExtensionFunction( 
	'glMultiTexCoord2sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord2sARB( GLenum(target), GLshort(s), GLshort(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2svARB = platform.createExtensionFunction( 
	'glMultiTexCoord2svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord2svARB( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3dARB = platform.createExtensionFunction( 
	'glMultiTexCoord3dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord3dARB( GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3dvARB = platform.createExtensionFunction( 
	'glMultiTexCoord3dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord3dvARB( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3fARB = platform.createExtensionFunction( 
	'glMultiTexCoord3fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord3fARB( GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3fvARB = platform.createExtensionFunction( 
	'glMultiTexCoord3fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord3fvARB( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3iARB = platform.createExtensionFunction( 
	'glMultiTexCoord3iARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord3iARB( GLenum(target), GLint(s), GLint(t), GLint(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3ivARB = platform.createExtensionFunction( 
	'glMultiTexCoord3ivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord3ivARB( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3sARB = platform.createExtensionFunction( 
	'glMultiTexCoord3sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord3sARB( GLenum(target), GLshort(s), GLshort(t), GLshort(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3svARB = platform.createExtensionFunction( 
	'glMultiTexCoord3svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord3svARB( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4dARB = platform.createExtensionFunction( 
	'glMultiTexCoord4dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord4dARB( GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r), GLdouble(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4dvARB = platform.createExtensionFunction( 
	'glMultiTexCoord4dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord4dvARB( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4fARB = platform.createExtensionFunction( 
	'glMultiTexCoord4fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord4fARB( GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4fvARB = platform.createExtensionFunction( 
	'glMultiTexCoord4fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord4fvARB( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4iARB = platform.createExtensionFunction( 
	'glMultiTexCoord4iARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord4iARB( GLenum(target), GLint(s), GLint(t), GLint(r), GLint(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4ivARB = platform.createExtensionFunction( 
	'glMultiTexCoord4ivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord4ivARB( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4sARB = platform.createExtensionFunction( 
	'glMultiTexCoord4sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord4sARB( GLenum(target), GLshort(s), GLshort(t), GLshort(r), GLshort(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4svARB = platform.createExtensionFunction( 
	'glMultiTexCoord4svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord4svARB( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)


def glInitMultitextureARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
