'''OpenGL extension ARB.draw_buffers

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.draw_buffers to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.draw_buffers import *
### END AUTOGENERATED SECTION
# This is untested...
glDrawBuffersARB = wrapper.wrapper( 
	glDrawBuffersARB,
).setPyConverter('n').setCConverter(
	'n', arrays.AsArrayTypedSize( 'bufs', arrays.GLenumArray ),
).setPyConverter(
	'bufs', arrays.AsArrayTyped( 'bufs', arrays.GLenumArray ),
).setCResolver( 
	'bufs', arrays.GLenumArray.dataPointer,
).setReturnValues(
	wrapper.returnPyArgument( 'bufs' )
)

from OpenGL.GL import glget
glget.addGLGetConstant( GL_MAX_DRAW_BUFFERS_ARB, (1,) )
# Should have output arrays for the buffers too???

