'''OpenGL extension NV.vertex_program4

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/vertex_program4.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_program4'
GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV', 0x88FD )
glVertexAttribI1iEXT = platform.createExtensionFunction( 
	'glVertexAttribI1iEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint,),
	doc = 'glVertexAttribI1iEXT( GLuint(index), GLint(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttribI2iEXT = platform.createExtensionFunction( 
	'glVertexAttribI2iEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLint,),
	doc = 'glVertexAttribI2iEXT( GLuint(index), GLint(x), GLint(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttribI3iEXT = platform.createExtensionFunction( 
	'glVertexAttribI3iEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glVertexAttribI3iEXT( GLuint(index), GLint(x), GLint(y), GLint(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttribI4iEXT = platform.createExtensionFunction( 
	'glVertexAttribI4iEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glVertexAttribI4iEXT( GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttribI1uiEXT = platform.createExtensionFunction( 
	'glVertexAttribI1uiEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLuint,),
	doc = 'glVertexAttribI1uiEXT( GLuint(index), GLuint(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttribI2uiEXT = platform.createExtensionFunction( 
	'glVertexAttribI2uiEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLuint, constants.GLuint,),
	doc = 'glVertexAttribI2uiEXT( GLuint(index), GLuint(x), GLuint(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttribI3uiEXT = platform.createExtensionFunction( 
	'glVertexAttribI3uiEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLuint, constants.GLuint, constants.GLuint,),
	doc = 'glVertexAttribI3uiEXT( GLuint(index), GLuint(x), GLuint(y), GLuint(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttribI4uiEXT = platform.createExtensionFunction( 
	'glVertexAttribI4uiEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLuint, constants.GLuint, constants.GLuint, constants.GLuint,),
	doc = 'glVertexAttribI4uiEXT( GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttribI1ivEXT = platform.createExtensionFunction( 
	'glVertexAttribI1ivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLintArray,),
	doc = 'glVertexAttribI1ivEXT( GLuint(index), GLintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI2ivEXT = platform.createExtensionFunction( 
	'glVertexAttribI2ivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLintArray,),
	doc = 'glVertexAttribI2ivEXT( GLuint(index), GLintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI3ivEXT = platform.createExtensionFunction( 
	'glVertexAttribI3ivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLintArray,),
	doc = 'glVertexAttribI3ivEXT( GLuint(index), GLintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI4ivEXT = platform.createExtensionFunction( 
	'glVertexAttribI4ivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLintArray,),
	doc = 'glVertexAttribI4ivEXT( GLuint(index), GLintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI1uivEXT = platform.createExtensionFunction( 
	'glVertexAttribI1uivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLuintArray,),
	doc = 'glVertexAttribI1uivEXT( GLuint(index), GLuintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI2uivEXT = platform.createExtensionFunction( 
	'glVertexAttribI2uivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLuintArray,),
	doc = 'glVertexAttribI2uivEXT( GLuint(index), GLuintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI3uivEXT = platform.createExtensionFunction( 
	'glVertexAttribI3uivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLuintArray,),
	doc = 'glVertexAttribI3uivEXT( GLuint(index), GLuintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI4uivEXT = platform.createExtensionFunction( 
	'glVertexAttribI4uivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLuintArray,),
	doc = 'glVertexAttribI4uivEXT( GLuint(index), GLuintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI4bvEXT = platform.createExtensionFunction( 
	'glVertexAttribI4bvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLbyteArray,),
	doc = 'glVertexAttribI4bvEXT( GLuint(index), GLbyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI4svEXT = platform.createExtensionFunction( 
	'glVertexAttribI4svEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttribI4svEXT( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI4ubvEXT = platform.createExtensionFunction( 
	'glVertexAttribI4ubvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLubyteArray,),
	doc = 'glVertexAttribI4ubvEXT( GLuint(index), GLubyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribI4usvEXT = platform.createExtensionFunction( 
	'glVertexAttribI4usvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLushortArray,),
	doc = 'glVertexAttribI4usvEXT( GLuint(index), GLushortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribIPointerEXT = platform.createExtensionFunction( 
	'glVertexAttribIPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glVertexAttribIPointerEXT( GLuint(index), GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer) ) -> None',
	argNames = ('index', 'size', 'type', 'stride', 'pointer',),
)

glGetVertexAttribIivEXT = platform.createExtensionFunction( 
	'glGetVertexAttribIivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetVertexAttribIivEXT( GLuint(index), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribIuivEXT = platform.createExtensionFunction( 
	'glGetVertexAttribIuivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLuintArray,),
	doc = 'glGetVertexAttribIuivEXT( GLuint(index), GLenum(pname), GLuintArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)


def glInitVertexProgram4NV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
