"""Constants for OpenGL.GLX

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL import constants as GLconstants
GLvoid = GLconstants.GLvoid

STRING = c_char_p
from OpenGL.constants import GL_BYTE
from OpenGL.constants import GL_DOUBLE
from OpenGL.constants import GL_FALSE
from OpenGL.constants import GL_FLOAT
from OpenGL.constants import GL_INT
from OpenGL.constants import GL_SHORT
from OpenGL.constants import GL_TRUE
from OpenGL.constants import GL_UNSIGNED_BYTE
from OpenGL.constants import GL_UNSIGNED_INT
from OpenGL.constants import GL_UNSIGNED_SHORT


CWX = Constant( 'CWX', 1)
CWY = Constant( 'CWY', 2)
FUNCPROTO = Constant( 'FUNCPROTO', 15)
GLX_3DFX_FULLSCREEN_MODE_MESA = Constant( 'GLX_3DFX_FULLSCREEN_MODE_MESA', 2)
GLX_3DFX_WINDOW_MODE_MESA = Constant( 'GLX_3DFX_WINDOW_MODE_MESA', 1)
GLX_ACCUM_ALPHA_SIZE = Constant( 'GLX_ACCUM_ALPHA_SIZE', 17)
GLX_ACCUM_BLUE_SIZE = Constant( 'GLX_ACCUM_BLUE_SIZE', 16)
GLX_ACCUM_BUFFER_BIT = Constant( 'GLX_ACCUM_BUFFER_BIT', 128)
GLX_ACCUM_BUFFER_BIT_SGIX = Constant( 'GLX_ACCUM_BUFFER_BIT_SGIX', 128)
GLX_ACCUM_GREEN_SIZE = Constant( 'GLX_ACCUM_GREEN_SIZE', 15)
GLX_ACCUM_RED_SIZE = Constant( 'GLX_ACCUM_RED_SIZE', 14)
GLX_ALPHA_SIZE = Constant( 'GLX_ALPHA_SIZE', 11)
GLX_AUX0_EXT = Constant( 'GLX_AUX0_EXT', 8418)
GLX_AUX1_EXT = Constant( 'GLX_AUX1_EXT', 8419)
GLX_AUX2_EXT = Constant( 'GLX_AUX2_EXT', 8420)
GLX_AUX3_EXT = Constant( 'GLX_AUX3_EXT', 8421)
GLX_AUX4_EXT = Constant( 'GLX_AUX4_EXT', 8422)
GLX_AUX5_EXT = Constant( 'GLX_AUX5_EXT', 8423)
GLX_AUX6_EXT = Constant( 'GLX_AUX6_EXT', 8424)
GLX_AUX7_EXT = Constant( 'GLX_AUX7_EXT', 8425)
GLX_AUX8_EXT = Constant( 'GLX_AUX8_EXT', 8426)
GLX_AUX9_EXT = Constant( 'GLX_AUX9_EXT', 8427)
GLX_AUX_BUFFERS = Constant( 'GLX_AUX_BUFFERS', 7)
GLX_AUX_BUFFERS_BIT = Constant( 'GLX_AUX_BUFFERS_BIT', 16)
GLX_AUX_BUFFERS_BIT_SGIX = Constant( 'GLX_AUX_BUFFERS_BIT_SGIX', 16)
GLX_BACK_LEFT_BUFFER_BIT = Constant( 'GLX_BACK_LEFT_BUFFER_BIT', 4)
GLX_BACK_LEFT_BUFFER_BIT_SGIX = Constant( 'GLX_BACK_LEFT_BUFFER_BIT_SGIX', 4)
GLX_BACK_LEFT_EXT = Constant( 'GLX_BACK_LEFT_EXT', 8416)
GLX_BACK_RIGHT_BUFFER_BIT = Constant( 'GLX_BACK_RIGHT_BUFFER_BIT', 8)
GLX_BACK_RIGHT_BUFFER_BIT_SGIX = Constant( 'GLX_BACK_RIGHT_BUFFER_BIT_SGIX', 8)
GLX_BACK_RIGHT_EXT = Constant( 'GLX_BACK_RIGHT_EXT', 8417)
GLX_BAD_ATTRIBUTE = Constant( 'GLX_BAD_ATTRIBUTE', 2)
GLX_BAD_CONTEXT = Constant( 'GLX_BAD_CONTEXT', 5)
GLX_BAD_ENUM = Constant( 'GLX_BAD_ENUM', 7)
GLX_BAD_HYPERPIPE_CONFIG_SGIX = Constant( 'GLX_BAD_HYPERPIPE_CONFIG_SGIX', 91)
GLX_BAD_HYPERPIPE_SGIX = Constant( 'GLX_BAD_HYPERPIPE_SGIX', 92)
GLX_BAD_SCREEN = Constant( 'GLX_BAD_SCREEN', 1)
GLX_BAD_VALUE = Constant( 'GLX_BAD_VALUE', 6)
GLX_BAD_VISUAL = Constant( 'GLX_BAD_VISUAL', 4)
GLX_BIND_TO_MIPMAP_TEXTURE_EXT = Constant( 'GLX_BIND_TO_MIPMAP_TEXTURE_EXT', 8402)
GLX_BIND_TO_TEXTURE_RGBA_EXT = Constant( 'GLX_BIND_TO_TEXTURE_RGBA_EXT', 8401)
GLX_BIND_TO_TEXTURE_RGB_EXT = Constant( 'GLX_BIND_TO_TEXTURE_RGB_EXT', 8400)
GLX_BIND_TO_TEXTURE_TARGETS_EXT = Constant( 'GLX_BIND_TO_TEXTURE_TARGETS_EXT', 8403)
GLX_BLENDED_RGBA_SGIS = Constant( 'GLX_BLENDED_RGBA_SGIS', 32805)
GLX_BLUE_SIZE = Constant( 'GLX_BLUE_SIZE', 10)
GLX_BUFFER_CLOBBER_MASK_SGIX = Constant( 'GLX_BUFFER_CLOBBER_MASK_SGIX', 134217728)
GLX_BUFFER_SIZE = Constant( 'GLX_BUFFER_SIZE', 2)
GLX_COLOR_INDEX_BIT = Constant( 'GLX_COLOR_INDEX_BIT', 2)
GLX_COLOR_INDEX_BIT_SGIX = Constant( 'GLX_COLOR_INDEX_BIT_SGIX', 2)
GLX_COLOR_INDEX_TYPE = Constant( 'GLX_COLOR_INDEX_TYPE', 32789)
GLX_COLOR_INDEX_TYPE_SGIX = Constant( 'GLX_COLOR_INDEX_TYPE_SGIX', 32789)
GLX_CONFIG_CAVEAT = Constant( 'GLX_CONFIG_CAVEAT', 32)
GLX_DAMAGED = Constant( 'GLX_DAMAGED', 32800)
GLX_DAMAGED_SGIX = Constant( 'GLX_DAMAGED_SGIX', 32800)
GLX_DEPTH_BUFFER_BIT = Constant( 'GLX_DEPTH_BUFFER_BIT', 32)
GLX_DEPTH_BUFFER_BIT_SGIX = Constant( 'GLX_DEPTH_BUFFER_BIT_SGIX', 32)
GLX_DEPTH_SIZE = Constant( 'GLX_DEPTH_SIZE', 12)
GLX_DIGITAL_MEDIA_PBUFFER_SGIX = Constant( 'GLX_DIGITAL_MEDIA_PBUFFER_SGIX', 32804)
GLX_DIRECT_COLOR = Constant( 'GLX_DIRECT_COLOR', 32771)
GLX_DIRECT_COLOR_EXT = Constant( 'GLX_DIRECT_COLOR_EXT', 32771)
GLX_DONT_CARE = Constant( 'GLX_DONT_CARE', 4294967295)
GLX_DOUBLEBUFFER = Constant( 'GLX_DOUBLEBUFFER', 5)
GLX_DRAWABLE_TYPE = Constant( 'GLX_DRAWABLE_TYPE', 32784)
GLX_DRAWABLE_TYPE_SGIX = Constant( 'GLX_DRAWABLE_TYPE_SGIX', 32784)
GLX_EVENT_MASK = Constant( 'GLX_EVENT_MASK', 32799)
GLX_EVENT_MASK_SGIX = Constant( 'GLX_EVENT_MASK_SGIX', 32799)
GLX_EXTENSIONS = Constant( 'GLX_EXTENSIONS', 3)
GLX_EXTENSION_NAME = Constant( 'GLX_EXTENSION_NAME', 'GLX')
GLX_FBCONFIG_ID = Constant( 'GLX_FBCONFIG_ID', 32787)
GLX_FBCONFIG_ID_SGIX = Constant( 'GLX_FBCONFIG_ID_SGIX', 32787)
GLX_FLOAT_COMPONENTS_NV = Constant( 'GLX_FLOAT_COMPONENTS_NV', 8368)
GLX_FRONT_LEFT_BUFFER_BIT = Constant( 'GLX_FRONT_LEFT_BUFFER_BIT', 1)
GLX_FRONT_LEFT_BUFFER_BIT_SGIX = Constant( 'GLX_FRONT_LEFT_BUFFER_BIT_SGIX', 1)
GLX_FRONT_LEFT_EXT = Constant( 'GLX_FRONT_LEFT_EXT', 8414)
GLX_FRONT_RIGHT_BUFFER_BIT = Constant( 'GLX_FRONT_RIGHT_BUFFER_BIT', 2)
GLX_FRONT_RIGHT_BUFFER_BIT_SGIX = Constant( 'GLX_FRONT_RIGHT_BUFFER_BIT_SGIX', 2)
GLX_FRONT_RIGHT_EXT = Constant( 'GLX_FRONT_RIGHT_EXT', 8415)
GLX_GLXEXT_VERSION = Constant( 'GLX_GLXEXT_VERSION', 11)
GLX_GRAY_SCALE = Constant( 'GLX_GRAY_SCALE', 32774)
GLX_GRAY_SCALE_EXT = Constant( 'GLX_GRAY_SCALE_EXT', 32774)
GLX_GREEN_SIZE = Constant( 'GLX_GREEN_SIZE', 9)
GLX_HEIGHT = Constant( 'GLX_HEIGHT', 32798)
GLX_HEIGHT_SGIX = Constant( 'GLX_HEIGHT_SGIX', 32798)
GLX_HYPERPIPE_DISPLAY_PIPE_SGIX = Constant( 'GLX_HYPERPIPE_DISPLAY_PIPE_SGIX', 1)
GLX_HYPERPIPE_ID_SGIX = Constant( 'GLX_HYPERPIPE_ID_SGIX', 32816)
GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX = Constant( 'GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX', 80)
GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX = Constant( 'GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX', 4)
GLX_HYPERPIPE_RENDER_PIPE_SGIX = Constant( 'GLX_HYPERPIPE_RENDER_PIPE_SGIX', 2)
GLX_HYPERPIPE_STEREO_SGIX = Constant( 'GLX_HYPERPIPE_STEREO_SGIX', 3)
GLX_LARGEST_PBUFFER = Constant( 'GLX_LARGEST_PBUFFER', 32796)
GLX_LARGEST_PBUFFER_SGIX = Constant( 'GLX_LARGEST_PBUFFER_SGIX', 32796)
GLX_LEVEL = Constant( 'GLX_LEVEL', 3)
GLX_MAX_PBUFFER_HEIGHT = Constant( 'GLX_MAX_PBUFFER_HEIGHT', 32791)
GLX_MAX_PBUFFER_HEIGHT_SGIX = Constant( 'GLX_MAX_PBUFFER_HEIGHT_SGIX', 32791)
GLX_MAX_PBUFFER_PIXELS = Constant( 'GLX_MAX_PBUFFER_PIXELS', 32792)
GLX_MAX_PBUFFER_PIXELS_SGIX = Constant( 'GLX_MAX_PBUFFER_PIXELS_SGIX', 32792)
GLX_MAX_PBUFFER_WIDTH = Constant( 'GLX_MAX_PBUFFER_WIDTH', 32790)
GLX_MAX_PBUFFER_WIDTH_SGIX = Constant( 'GLX_MAX_PBUFFER_WIDTH_SGIX', 32790)
GLX_MIPMAP_TEXTURE_EXT = Constant( 'GLX_MIPMAP_TEXTURE_EXT', 8407)
GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS = Constant( 'GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS', 32807)
GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS = Constant( 'GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS', 32806)
GLX_NONE = Constant( 'GLX_NONE', 32768)
GLX_NONE_EXT = Constant( 'GLX_NONE_EXT', 32768)
GLX_NON_CONFORMANT_CONFIG = Constant( 'GLX_NON_CONFORMANT_CONFIG', 32781)
GLX_NON_CONFORMANT_VISUAL_EXT = Constant( 'GLX_NON_CONFORMANT_VISUAL_EXT', 32781)
GLX_NO_EXTENSION = Constant( 'GLX_NO_EXTENSION', 3)
GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX = Constant( 'GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX', 32794)
GLX_OPTIMAL_PBUFFER_WIDTH_SGIX = Constant( 'GLX_OPTIMAL_PBUFFER_WIDTH_SGIX', 32793)
GLX_PBUFFER = Constant( 'GLX_PBUFFER', 32803)
GLX_PBUFFER_BIT = Constant( 'GLX_PBUFFER_BIT', 4)
GLX_PBUFFER_BIT_SGIX = Constant( 'GLX_PBUFFER_BIT_SGIX', 4)
GLX_PBUFFER_CLOBBER_MASK = Constant( 'GLX_PBUFFER_CLOBBER_MASK', 134217728)
GLX_PBUFFER_HEIGHT = Constant( 'GLX_PBUFFER_HEIGHT', 32832)
GLX_PBUFFER_SGIX = Constant( 'GLX_PBUFFER_SGIX', 32803)
GLX_PBUFFER_WIDTH = Constant( 'GLX_PBUFFER_WIDTH', 32833)
GLX_PIPE_RECT_LIMITS_SGIX = Constant( 'GLX_PIPE_RECT_LIMITS_SGIX', 2)
GLX_PIPE_RECT_SGIX = Constant( 'GLX_PIPE_RECT_SGIX', 1)
GLX_PIXMAP_BIT = Constant( 'GLX_PIXMAP_BIT', 2)
GLX_PIXMAP_BIT_SGIX = Constant( 'GLX_PIXMAP_BIT_SGIX', 2)
GLX_PRESERVED_CONTENTS = Constant( 'GLX_PRESERVED_CONTENTS', 32795)
GLX_PRESERVED_CONTENTS_SGIX = Constant( 'GLX_PRESERVED_CONTENTS_SGIX', 32795)
GLX_PSEUDO_COLOR = Constant( 'GLX_PSEUDO_COLOR', 32772)
GLX_PSEUDO_COLOR_EXT = Constant( 'GLX_PSEUDO_COLOR_EXT', 32772)
GLX_RED_SIZE = Constant( 'GLX_RED_SIZE', 8)
GLX_RENDER_TYPE = Constant( 'GLX_RENDER_TYPE', 32785)
GLX_RENDER_TYPE_SGIX = Constant( 'GLX_RENDER_TYPE_SGIX', 32785)
GLX_RGBA = Constant( 'GLX_RGBA', 4)
GLX_RGBA_BIT = Constant( 'GLX_RGBA_BIT', 1)
GLX_RGBA_BIT_SGIX = Constant( 'GLX_RGBA_BIT_SGIX', 1)
GLX_RGBA_FLOAT_BIT_ARB = Constant( 'GLX_RGBA_FLOAT_BIT_ARB', 4)
GLX_RGBA_FLOAT_TYPE_ARB = Constant( 'GLX_RGBA_FLOAT_TYPE_ARB', 8377)
GLX_RGBA_TYPE = Constant( 'GLX_RGBA_TYPE', 32788)
GLX_RGBA_TYPE_SGIX = Constant( 'GLX_RGBA_TYPE_SGIX', 32788)
GLX_SAMPLES = Constant( 'GLX_SAMPLES', 100001)
GLX_SAMPLES_3DFX = Constant( 'GLX_SAMPLES_3DFX', 32849)
GLX_SAMPLES_ARB = Constant( 'GLX_SAMPLES_ARB', 100001)
GLX_SAMPLES_SGIS = Constant( 'GLX_SAMPLES_SGIS', 100001)
GLX_SAMPLE_BUFFERS = Constant( 'GLX_SAMPLE_BUFFERS', 100000)
GLX_SAMPLE_BUFFERS_3DFX = Constant( 'GLX_SAMPLE_BUFFERS_3DFX', 32848)
GLX_SAMPLE_BUFFERS_ARB = Constant( 'GLX_SAMPLE_BUFFERS_ARB', 100000)
GLX_SAMPLE_BUFFERS_BIT_SGIX = Constant( 'GLX_SAMPLE_BUFFERS_BIT_SGIX', 256)
GLX_SAMPLE_BUFFERS_SGIS = Constant( 'GLX_SAMPLE_BUFFERS_SGIS', 100000)
GLX_SAVED = Constant( 'GLX_SAVED', 32801)
GLX_SAVED_SGIX = Constant( 'GLX_SAVED_SGIX', 32801)
GLX_SCREEN = Constant( 'GLX_SCREEN', 32780)
GLX_SCREEN_EXT = Constant( 'GLX_SCREEN_EXT', 32780)
GLX_SHARE_CONTEXT_EXT = Constant( 'GLX_SHARE_CONTEXT_EXT', 32778)
GLX_SLOW_CONFIG = Constant( 'GLX_SLOW_CONFIG', 32769)
GLX_SLOW_VISUAL_EXT = Constant( 'GLX_SLOW_VISUAL_EXT', 32769)
GLX_STATIC_COLOR = Constant( 'GLX_STATIC_COLOR', 32773)
GLX_STATIC_COLOR_EXT = Constant( 'GLX_STATIC_COLOR_EXT', 32773)
GLX_STATIC_GRAY = Constant( 'GLX_STATIC_GRAY', 32775)
GLX_STATIC_GRAY_EXT = Constant( 'GLX_STATIC_GRAY_EXT', 32775)
GLX_STENCIL_BUFFER_BIT = Constant( 'GLX_STENCIL_BUFFER_BIT', 64)
GLX_STENCIL_BUFFER_BIT_SGIX = Constant( 'GLX_STENCIL_BUFFER_BIT_SGIX', 64)
GLX_STENCIL_SIZE = Constant( 'GLX_STENCIL_SIZE', 13)
GLX_STEREO = Constant( 'GLX_STEREO', 6)
GLX_SWAP_COPY_OML = Constant( 'GLX_SWAP_COPY_OML', 32866)
GLX_SWAP_EXCHANGE_OML = Constant( 'GLX_SWAP_EXCHANGE_OML', 32865)
GLX_SWAP_METHOD_OML = Constant( 'GLX_SWAP_METHOD_OML', 32864)
GLX_SWAP_UNDEFINED_OML = Constant( 'GLX_SWAP_UNDEFINED_OML', 32867)
GLX_SYNC_FRAME_SGIX = Constant( 'GLX_SYNC_FRAME_SGIX', 0)
GLX_SYNC_SWAP_SGIX = Constant( 'GLX_SYNC_SWAP_SGIX', 1)
GLX_TEXTURE_1D_BIT_EXT = Constant( 'GLX_TEXTURE_1D_BIT_EXT', 1)
GLX_TEXTURE_1D_EXT = Constant( 'GLX_TEXTURE_1D_EXT', 8411)
GLX_TEXTURE_2D_BIT_EXT = Constant( 'GLX_TEXTURE_2D_BIT_EXT', 2)
GLX_TEXTURE_2D_EXT = Constant( 'GLX_TEXTURE_2D_EXT', 8412)
GLX_TEXTURE_FORMAT_EXT = Constant( 'GLX_TEXTURE_FORMAT_EXT', 8405)
GLX_TEXTURE_FORMAT_NONE_EXT = Constant( 'GLX_TEXTURE_FORMAT_NONE_EXT', 8408)
GLX_TEXTURE_FORMAT_RGBA_EXT = Constant( 'GLX_TEXTURE_FORMAT_RGBA_EXT', 8410)
GLX_TEXTURE_FORMAT_RGB_EXT = Constant( 'GLX_TEXTURE_FORMAT_RGB_EXT', 8409)
GLX_TEXTURE_RECTANGLE_BIT_EXT = Constant( 'GLX_TEXTURE_RECTANGLE_BIT_EXT', 4)
GLX_TEXTURE_RECTANGLE_EXT = Constant( 'GLX_TEXTURE_RECTANGLE_EXT', 8413)
GLX_TEXTURE_TARGET_EXT = Constant( 'GLX_TEXTURE_TARGET_EXT', 8406)
GLX_TRANSPARENT_ALPHA_VALUE = Constant( 'GLX_TRANSPARENT_ALPHA_VALUE', 40)
GLX_TRANSPARENT_ALPHA_VALUE_EXT = Constant( 'GLX_TRANSPARENT_ALPHA_VALUE_EXT', 40)
GLX_TRANSPARENT_BLUE_VALUE = Constant( 'GLX_TRANSPARENT_BLUE_VALUE', 39)
GLX_TRANSPARENT_BLUE_VALUE_EXT = Constant( 'GLX_TRANSPARENT_BLUE_VALUE_EXT', 39)
GLX_TRANSPARENT_GREEN_VALUE = Constant( 'GLX_TRANSPARENT_GREEN_VALUE', 38)
GLX_TRANSPARENT_GREEN_VALUE_EXT = Constant( 'GLX_TRANSPARENT_GREEN_VALUE_EXT', 38)
GLX_TRANSPARENT_INDEX = Constant( 'GLX_TRANSPARENT_INDEX', 32777)
GLX_TRANSPARENT_INDEX_EXT = Constant( 'GLX_TRANSPARENT_INDEX_EXT', 32777)
GLX_TRANSPARENT_INDEX_VALUE = Constant( 'GLX_TRANSPARENT_INDEX_VALUE', 36)
GLX_TRANSPARENT_INDEX_VALUE_EXT = Constant( 'GLX_TRANSPARENT_INDEX_VALUE_EXT', 36)
GLX_TRANSPARENT_RED_VALUE = Constant( 'GLX_TRANSPARENT_RED_VALUE', 37)
GLX_TRANSPARENT_RED_VALUE_EXT = Constant( 'GLX_TRANSPARENT_RED_VALUE_EXT', 37)
GLX_TRANSPARENT_RGB = Constant( 'GLX_TRANSPARENT_RGB', 32776)
GLX_TRANSPARENT_RGB_EXT = Constant( 'GLX_TRANSPARENT_RGB_EXT', 32776)
GLX_TRANSPARENT_TYPE = Constant( 'GLX_TRANSPARENT_TYPE', 35)
GLX_TRANSPARENT_TYPE_EXT = Constant( 'GLX_TRANSPARENT_TYPE_EXT', 35)
GLX_TRUE_COLOR = Constant( 'GLX_TRUE_COLOR', 32770)
GLX_TRUE_COLOR_EXT = Constant( 'GLX_TRUE_COLOR_EXT', 32770)
GLX_USE_GL = Constant( 'GLX_USE_GL', 1)
GLX_VENDOR = Constant( 'GLX_VENDOR', 1)
GLX_VERSION = Constant( 'GLX_VERSION', 2)
GLX_VERSION_1_1 = Constant( 'GLX_VERSION_1_1', 1)
GLX_VERSION_1_2 = Constant( 'GLX_VERSION_1_2', 1)
GLX_VERSION_1_3 = Constant( 'GLX_VERSION_1_3', 1)
GLX_VERSION_1_4 = Constant( 'GLX_VERSION_1_4', 1)
GLX_VISUAL_CAVEAT_EXT = Constant( 'GLX_VISUAL_CAVEAT_EXT', 32)
GLX_VISUAL_ID = Constant( 'GLX_VISUAL_ID', 32779)
GLX_VISUAL_ID_EXT = Constant( 'GLX_VISUAL_ID_EXT', 32779)
GLX_VISUAL_SELECT_GROUP_SGIX = Constant( 'GLX_VISUAL_SELECT_GROUP_SGIX', 32808)
GLX_WIDTH = Constant( 'GLX_WIDTH', 32797)
GLX_WIDTH_SGIX = Constant( 'GLX_WIDTH_SGIX', 32797)
GLX_WINDOW = Constant( 'GLX_WINDOW', 32802)
GLX_WINDOW_BIT = Constant( 'GLX_WINDOW_BIT', 1)
GLX_WINDOW_BIT_SGIX = Constant( 'GLX_WINDOW_BIT_SGIX', 1)
GLX_WINDOW_SGIX = Constant( 'GLX_WINDOW_SGIX', 32802)
GLX_X_RENDERABLE = Constant( 'GLX_X_RENDERABLE', 32786)
GLX_X_RENDERABLE_SGIX = Constant( 'GLX_X_RENDERABLE_SGIX', 32786)
GLX_X_VISUAL_TYPE = Constant( 'GLX_X_VISUAL_TYPE', 34)
GLX_X_VISUAL_TYPE_EXT = Constant( 'GLX_X_VISUAL_TYPE_EXT', 34)
GLX_Y_INVERTED_EXT = Constant( 'GLX_Y_INVERTED_EXT', 8404)
GL_ALL_CLIENT_ATTRIB_BITS = Constant( 'GL_ALL_CLIENT_ATTRIB_BITS', 4294967295)
GL_ALPHA_BLEND_EQUATION_ATI = Constant( 'GL_ALPHA_BLEND_EQUATION_ATI', 34877)
GL_DEBUG_ASSERT_MESA = Constant( 'GL_DEBUG_ASSERT_MESA', 34651)
GL_DEBUG_OBJECT_MESA = Constant( 'GL_DEBUG_OBJECT_MESA', 34649)
GL_DEBUG_PRINT_MESA = Constant( 'GL_DEBUG_PRINT_MESA', 34650)
GL_DEPTH_STENCIL_MESA = Constant( 'GL_DEPTH_STENCIL_MESA', 34640)
GL_FRAGMENT_PROGRAM_CALLBACK_DATA_MESA = Constant( 'GL_FRAGMENT_PROGRAM_CALLBACK_DATA_MESA', 35763)
GL_FRAGMENT_PROGRAM_CALLBACK_FUNC_MESA = Constant( 'GL_FRAGMENT_PROGRAM_CALLBACK_FUNC_MESA', 35762)
GL_FRAGMENT_PROGRAM_CALLBACK_MESA = Constant( 'GL_FRAGMENT_PROGRAM_CALLBACK_MESA', 35761)
GL_FRAGMENT_PROGRAM_POSITION_MESA = Constant( 'GL_FRAGMENT_PROGRAM_POSITION_MESA', 35760)
GL_TRACE_ALL_BITS_MESA = Constant( 'GL_TRACE_ALL_BITS_MESA', 65535)
GL_TRACE_ARRAYS_BIT_MESA = Constant( 'GL_TRACE_ARRAYS_BIT_MESA', 4)
GL_TRACE_ERRORS_BIT_MESA = Constant( 'GL_TRACE_ERRORS_BIT_MESA', 32)
GL_TRACE_MASK_MESA = Constant( 'GL_TRACE_MASK_MESA', 34645)
GL_TRACE_NAME_MESA = Constant( 'GL_TRACE_NAME_MESA', 34646)
GL_TRACE_OPERATIONS_BIT_MESA = Constant( 'GL_TRACE_OPERATIONS_BIT_MESA', 1)
GL_TRACE_PIXELS_BIT_MESA = Constant( 'GL_TRACE_PIXELS_BIT_MESA', 16)
GL_TRACE_PRIMITIVES_BIT_MESA = Constant( 'GL_TRACE_PRIMITIVES_BIT_MESA', 2)
GL_TRACE_TEXTURES_BIT_MESA = Constant( 'GL_TRACE_TEXTURES_BIT_MESA', 8)
GL_UNSIGNED_INT_24_8_MESA = Constant( 'GL_UNSIGNED_INT_24_8_MESA', 34641)
GL_UNSIGNED_INT_8_24_REV_MESA = Constant( 'GL_UNSIGNED_INT_8_24_REV_MESA', 34642)
GL_UNSIGNED_SHORT_15_1_MESA = Constant( 'GL_UNSIGNED_SHORT_15_1_MESA', 34643)
GL_UNSIGNED_SHORT_1_15_REV_MESA = Constant( 'GL_UNSIGNED_SHORT_1_15_REV_MESA', 34644)
GL_VERTEX_PROGRAM_CALLBACK_DATA_MESA = Constant( 'GL_VERTEX_PROGRAM_CALLBACK_DATA_MESA', 35767)
GL_VERTEX_PROGRAM_CALLBACK_FUNC_MESA = Constant( 'GL_VERTEX_PROGRAM_CALLBACK_FUNC_MESA', 35766)
GL_VERTEX_PROGRAM_CALLBACK_MESA = Constant( 'GL_VERTEX_PROGRAM_CALLBACK_MESA', 35765)
GL_VERTEX_PROGRAM_POSITION_MESA = Constant( 'GL_VERTEX_PROGRAM_POSITION_MESA', 35764)
XCNOENT = Constant( 'XCNOENT', 2)
XCNOMEM = Constant( 'XCNOMEM', 1)
XCSUCCESS = Constant( 'XCSUCCESS', 0)
XK_0 = Constant( 'XK_0', 48)
XK_1 = Constant( 'XK_1', 49)
XK_2 = Constant( 'XK_2', 50)
XK_3 = Constant( 'XK_3', 51)
XK_4 = Constant( 'XK_4', 52)
XK_5 = Constant( 'XK_5', 53)
XK_6 = Constant( 'XK_6', 54)
XK_7 = Constant( 'XK_7', 55)
XK_8 = Constant( 'XK_8', 56)
XK_9 = Constant( 'XK_9', 57)
XK_A = Constant( 'XK_A', 65)
XK_AE = Constant( 'XK_AE', 198)
XK_B = Constant( 'XK_B', 66)
XK_C = Constant( 'XK_C', 67)
XK_D = Constant( 'XK_D', 68)
XK_E = Constant( 'XK_E', 69)
XK_ENG = Constant( 'XK_ENG', 957)
XK_ETH = Constant( 'XK_ETH', 208)
XK_F = Constant( 'XK_F', 70)
XK_F1 = Constant( 'XK_F1', 65470)
XK_F10 = Constant( 'XK_F10', 65479)
XK_F11 = Constant( 'XK_F11', 65480)
XK_F12 = Constant( 'XK_F12', 65481)
XK_F13 = Constant( 'XK_F13', 65482)
XK_F14 = Constant( 'XK_F14', 65483)
XK_F15 = Constant( 'XK_F15', 65484)
XK_F16 = Constant( 'XK_F16', 65485)
XK_F17 = Constant( 'XK_F17', 65486)
XK_F18 = Constant( 'XK_F18', 65487)
XK_F19 = Constant( 'XK_F19', 65488)
XK_F2 = Constant( 'XK_F2', 65471)
XK_F20 = Constant( 'XK_F20', 65489)
XK_F21 = Constant( 'XK_F21', 65490)
XK_F22 = Constant( 'XK_F22', 65491)
XK_F23 = Constant( 'XK_F23', 65492)
XK_F24 = Constant( 'XK_F24', 65493)
XK_F25 = Constant( 'XK_F25', 65494)
XK_F26 = Constant( 'XK_F26', 65495)
XK_F27 = Constant( 'XK_F27', 65496)
XK_F28 = Constant( 'XK_F28', 65497)
XK_F29 = Constant( 'XK_F29', 65498)
XK_F3 = Constant( 'XK_F3', 65472)
XK_F30 = Constant( 'XK_F30', 65499)
XK_F31 = Constant( 'XK_F31', 65500)
XK_F32 = Constant( 'XK_F32', 65501)
XK_F33 = Constant( 'XK_F33', 65502)
XK_F34 = Constant( 'XK_F34', 65503)
XK_F35 = Constant( 'XK_F35', 65504)
XK_F4 = Constant( 'XK_F4', 65473)
XK_F5 = Constant( 'XK_F5', 65474)
XK_F6 = Constant( 'XK_F6', 65475)
XK_F7 = Constant( 'XK_F7', 65476)
XK_F8 = Constant( 'XK_F8', 65477)
XK_F9 = Constant( 'XK_F9', 65478)
XK_G = Constant( 'XK_G', 71)
XK_H = Constant( 'XK_H', 72)
XK_I = Constant( 'XK_I', 73)
XK_J = Constant( 'XK_J', 74)
XK_K = Constant( 'XK_K', 75)
XK_KP_0 = Constant( 'XK_KP_0', 65456)
XK_KP_1 = Constant( 'XK_KP_1', 65457)
XK_KP_2 = Constant( 'XK_KP_2', 65458)
XK_KP_3 = Constant( 'XK_KP_3', 65459)
XK_KP_4 = Constant( 'XK_KP_4', 65460)
XK_KP_5 = Constant( 'XK_KP_5', 65461)
XK_KP_6 = Constant( 'XK_KP_6', 65462)
XK_KP_7 = Constant( 'XK_KP_7', 65463)
XK_KP_8 = Constant( 'XK_KP_8', 65464)
XK_KP_9 = Constant( 'XK_KP_9', 65465)
XK_KP_F1 = Constant( 'XK_KP_F1', 65425)
XK_KP_F2 = Constant( 'XK_KP_F2', 65426)
XK_KP_F3 = Constant( 'XK_KP_F3', 65427)
XK_KP_F4 = Constant( 'XK_KP_F4', 65428)
XK_L = Constant( 'XK_L', 76)
XK_L1 = Constant( 'XK_L1', 65480)
XK_L10 = Constant( 'XK_L10', 65489)
XK_L2 = Constant( 'XK_L2', 65481)
XK_L3 = Constant( 'XK_L3', 65482)
XK_L4 = Constant( 'XK_L4', 65483)
XK_L5 = Constant( 'XK_L5', 65484)
XK_L6 = Constant( 'XK_L6', 65485)
XK_L7 = Constant( 'XK_L7', 65486)
XK_L8 = Constant( 'XK_L8', 65487)
XK_L9 = Constant( 'XK_L9', 65488)
XK_M = Constant( 'XK_M', 77)
XK_N = Constant( 'XK_N', 78)
XK_O = Constant( 'XK_O', 79)
XK_OE = Constant( 'XK_OE', 5052)
XK_P = Constant( 'XK_P', 80)
XK_Q = Constant( 'XK_Q', 81)
XK_R = Constant( 'XK_R', 82)
XK_R1 = Constant( 'XK_R1', 65490)
XK_R10 = Constant( 'XK_R10', 65499)
XK_R11 = Constant( 'XK_R11', 65500)
XK_R12 = Constant( 'XK_R12', 65501)
XK_R13 = Constant( 'XK_R13', 65502)
XK_R14 = Constant( 'XK_R14', 65503)
XK_R15 = Constant( 'XK_R15', 65504)
XK_R2 = Constant( 'XK_R2', 65491)
XK_R3 = Constant( 'XK_R3', 65492)
XK_R4 = Constant( 'XK_R4', 65493)
XK_R5 = Constant( 'XK_R5', 65494)
XK_R6 = Constant( 'XK_R6', 65495)
XK_R7 = Constant( 'XK_R7', 65496)
XK_R8 = Constant( 'XK_R8', 65497)
XK_R9 = Constant( 'XK_R9', 65498)
XK_S = Constant( 'XK_S', 83)
XK_SCHWA = Constant( 'XK_SCHWA', 16777615)
XK_T = Constant( 'XK_T', 84)
XK_THORN = Constant( 'XK_THORN', 222)
XK_U = Constant( 'XK_U', 85)
XK_V = Constant( 'XK_V', 86)
XK_W = Constant( 'XK_W', 87)
XK_X = Constant( 'XK_X', 88)
XK_Y = Constant( 'XK_Y', 89)
XK_Z = Constant( 'XK_Z', 90)
X_HAVE_UTF8_STRING = Constant( 'X_HAVE_UTF8_STRING', 1)
X_PROTOCOL = Constant( 'X_PROTOCOL', 11)
X_PROTOCOL_REVISION = Constant( 'X_PROTOCOL_REVISION', 0)
_ATFILE_SOURCE = Constant( '_ATFILE_SOURCE', 1)
_BITS_PTHREADTYPES_H = Constant( '_BITS_PTHREADTYPES_H', 1)
_BITS_TYPESIZES_H = Constant( '_BITS_TYPESIZES_H', 1)
_BITS_TYPES_H = Constant( '_BITS_TYPES_H', 1)
_BITS_WCHAR_H = Constant( '_BITS_WCHAR_H', 1)
_BSD_SOURCE = Constant( '_BSD_SOURCE', 1)
_ENDIAN_H = Constant( '_ENDIAN_H', 1)
_FEATURES_H = Constant( '_FEATURES_H', 1)
_INTTYPES_H = Constant( '_INTTYPES_H', 1)
_ISOC99_SOURCE = Constant( '_ISOC99_SOURCE', 1)
_LARGEFILE64_SOURCE = Constant( '_LARGEFILE64_SOURCE', 1)
_LARGEFILE_SOURCE = Constant( '_LARGEFILE_SOURCE', 1)
_POSIX_C_SOURCE = Constant( '_POSIX_C_SOURCE', 199506)
_POSIX_SOURCE = Constant( '_POSIX_SOURCE', 1)
_SIGSET_NWORDS = Constant( '_SIGSET_NWORDS', 16)
_STDINT_H = Constant( '_STDINT_H', 1)
_STRUCT_TIMEVAL = Constant( '_STRUCT_TIMEVAL', 1)
_SVID_SOURCE = Constant( '_SVID_SOURCE', 1)
_SYS_CDEFS_H = Constant( '_SYS_CDEFS_H', 1)
_SYS_SELECT_H = Constant( '_SYS_SELECT_H', 1)
_SYS_SYSMACROS_H = Constant( '_SYS_SYSMACROS_H', 1)
_SYS_TYPES_H = Constant( '_SYS_TYPES_H', 1)
_XOPEN_SOURCE = Constant( '_XOPEN_SOURCE', 600)
_XOPEN_SOURCE_EXTENDED = Constant( '_XOPEN_SOURCE_EXTENDED', 1)
__BIG_ENDIAN = Constant( '__BIG_ENDIAN', 4321)
__BIT_TYPES_DEFINED__ = Constant( '__BIT_TYPES_DEFINED__', 1)
__FD_SETSIZE = Constant( '__FD_SETSIZE', 1024)
__GLIBC_HAVE_LONG_LONG = Constant( '__GLIBC_HAVE_LONG_LONG', 1)
__GLIBC_MINOR__ = Constant( '__GLIBC_MINOR__', 4)
__GLIBC__ = Constant( '__GLIBC__', 2)
__GNU_LIBRARY__ = Constant( '__GNU_LIBRARY__', 6)
__LITTLE_ENDIAN = Constant( '__LITTLE_ENDIAN', 1234)
__NFDBITS = Constant( '__NFDBITS', 64)
__PDP_ENDIAN = Constant( '__PDP_ENDIAN', 3412)
__PTHREAD_MUTEX_HAVE_PREV = Constant( '__PTHREAD_MUTEX_HAVE_PREV', 1)
__SIZEOF_PTHREAD_ATTR_T = Constant( '__SIZEOF_PTHREAD_ATTR_T', 56)
__SIZEOF_PTHREAD_BARRIERATTR_T = Constant( '__SIZEOF_PTHREAD_BARRIERATTR_T', 4)
__SIZEOF_PTHREAD_BARRIER_T = Constant( '__SIZEOF_PTHREAD_BARRIER_T', 32)
__SIZEOF_PTHREAD_CONDATTR_T = Constant( '__SIZEOF_PTHREAD_CONDATTR_T', 4)
__SIZEOF_PTHREAD_COND_T = Constant( '__SIZEOF_PTHREAD_COND_T', 48)
__SIZEOF_PTHREAD_MUTEXATTR_T = Constant( '__SIZEOF_PTHREAD_MUTEXATTR_T', 4)
__SIZEOF_PTHREAD_MUTEX_T = Constant( '__SIZEOF_PTHREAD_MUTEX_T', 40)
__SIZEOF_PTHREAD_RWLOCKATTR_T = Constant( '__SIZEOF_PTHREAD_RWLOCKATTR_T', 8)
__SIZEOF_PTHREAD_RWLOCK_T = Constant( '__SIZEOF_PTHREAD_RWLOCK_T', 56)
__STDC_IEC_559_COMPLEX__ = Constant( '__STDC_IEC_559_COMPLEX__', 1)
__STDC_IEC_559__ = Constant( '__STDC_IEC_559__', 1)
__STDC_ISO_10646__ = Constant( '__STDC_ISO_10646__', 200009)
__USE_ANSI = Constant( '__USE_ANSI', 1)
__USE_ATFILE = Constant( '__USE_ATFILE', 1)
__USE_BSD = Constant( '__USE_BSD', 1)
__USE_FORTIFY_LEVEL = Constant( '__USE_FORTIFY_LEVEL', 0)
__USE_GNU = Constant( '__USE_GNU', 1)
__USE_ISOC99 = Constant( '__USE_ISOC99', 1)
__USE_LARGEFILE = Constant( '__USE_LARGEFILE', 1)
__USE_LARGEFILE64 = Constant( '__USE_LARGEFILE64', 1)
__USE_MISC = Constant( '__USE_MISC', 1)
__USE_POSIX = Constant( '__USE_POSIX', 1)
__USE_POSIX199309 = Constant( '__USE_POSIX199309', 1)
__USE_POSIX199506 = Constant( '__USE_POSIX199506', 1)
__USE_POSIX2 = Constant( '__USE_POSIX2', 1)
__USE_SVID = Constant( '__USE_SVID', 1)
__USE_UNIX98 = Constant( '__USE_UNIX98', 1)
__USE_XOPEN = Constant( '__USE_XOPEN', 1)
__USE_XOPEN2K = Constant( '__USE_XOPEN2K', 1)
__USE_XOPEN_EXTENDED = Constant( '__USE_XOPEN_EXTENDED', 1)
__WCHAR_MAX = Constant( '__WCHAR_MAX', 2147483647)
__WCHAR_MIN = Constant( '__WCHAR_MIN', -2147483648)
__WORDSIZE = Constant( '__WORDSIZE', 64)
__WORDSIZE_COMPAT32 = Constant( '__WORDSIZE_COMPAT32', 1)
__all__ = [
	'CWX',
	'CWY',
	'FUNCPROTO',
	'GLX_3DFX_FULLSCREEN_MODE_MESA',
	'GLX_3DFX_WINDOW_MODE_MESA',
	'GLX_ACCUM_ALPHA_SIZE',
	'GLX_ACCUM_BLUE_SIZE',
	'GLX_ACCUM_BUFFER_BIT',
	'GLX_ACCUM_BUFFER_BIT_SGIX',
	'GLX_ACCUM_GREEN_SIZE',
	'GLX_ACCUM_RED_SIZE',
	'GLX_ALPHA_SIZE',
	'GLX_AUX0_EXT',
	'GLX_AUX1_EXT',
	'GLX_AUX2_EXT',
	'GLX_AUX3_EXT',
	'GLX_AUX4_EXT',
	'GLX_AUX5_EXT',
	'GLX_AUX6_EXT',
	'GLX_AUX7_EXT',
	'GLX_AUX8_EXT',
	'GLX_AUX9_EXT',
	'GLX_AUX_BUFFERS',
	'GLX_AUX_BUFFERS_BIT',
	'GLX_AUX_BUFFERS_BIT_SGIX',
	'GLX_BACK_LEFT_BUFFER_BIT',
	'GLX_BACK_LEFT_BUFFER_BIT_SGIX',
	'GLX_BACK_LEFT_EXT',
	'GLX_BACK_RIGHT_BUFFER_BIT',
	'GLX_BACK_RIGHT_BUFFER_BIT_SGIX',
	'GLX_BACK_RIGHT_EXT',
	'GLX_BAD_ATTRIBUTE',
	'GLX_BAD_CONTEXT',
	'GLX_BAD_ENUM',
	'GLX_BAD_HYPERPIPE_CONFIG_SGIX',
	'GLX_BAD_HYPERPIPE_SGIX',
	'GLX_BAD_SCREEN',
	'GLX_BAD_VALUE',
	'GLX_BAD_VISUAL',
	'GLX_BIND_TO_MIPMAP_TEXTURE_EXT',
	'GLX_BIND_TO_TEXTURE_RGBA_EXT',
	'GLX_BIND_TO_TEXTURE_RGB_EXT',
	'GLX_BIND_TO_TEXTURE_TARGETS_EXT',
	'GLX_BLENDED_RGBA_SGIS',
	'GLX_BLUE_SIZE',
	'GLX_BUFFER_CLOBBER_MASK_SGIX',
	'GLX_BUFFER_SIZE',
	'GLX_COLOR_INDEX_BIT',
	'GLX_COLOR_INDEX_BIT_SGIX',
	'GLX_COLOR_INDEX_TYPE',
	'GLX_COLOR_INDEX_TYPE_SGIX',
	'GLX_CONFIG_CAVEAT',
	'GLX_DAMAGED',
	'GLX_DAMAGED_SGIX',
	'GLX_DEPTH_BUFFER_BIT',
	'GLX_DEPTH_BUFFER_BIT_SGIX',
	'GLX_DEPTH_SIZE',
	'GLX_DIGITAL_MEDIA_PBUFFER_SGIX',
	'GLX_DIRECT_COLOR',
	'GLX_DIRECT_COLOR_EXT',
	'GLX_DONT_CARE',
	'GLX_DOUBLEBUFFER',
	'GLX_DRAWABLE_TYPE',
	'GLX_DRAWABLE_TYPE_SGIX',
	'GLX_EVENT_MASK',
	'GLX_EVENT_MASK_SGIX',
	'GLX_EXTENSIONS',
	'GLX_EXTENSION_NAME',
	'GLX_FBCONFIG_ID',
	'GLX_FBCONFIG_ID_SGIX',
	'GLX_FLOAT_COMPONENTS_NV',
	'GLX_FRONT_LEFT_BUFFER_BIT',
	'GLX_FRONT_LEFT_BUFFER_BIT_SGIX',
	'GLX_FRONT_LEFT_EXT',
	'GLX_FRONT_RIGHT_BUFFER_BIT',
	'GLX_FRONT_RIGHT_BUFFER_BIT_SGIX',
	'GLX_FRONT_RIGHT_EXT',
	'GLX_GLXEXT_VERSION',
	'GLX_GRAY_SCALE',
	'GLX_GRAY_SCALE_EXT',
	'GLX_GREEN_SIZE',
	'GLX_HEIGHT',
	'GLX_HEIGHT_SGIX',
	'GLX_HYPERPIPE_DISPLAY_PIPE_SGIX',
	'GLX_HYPERPIPE_ID_SGIX',
	'GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX',
	'GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX',
	'GLX_HYPERPIPE_RENDER_PIPE_SGIX',
	'GLX_HYPERPIPE_STEREO_SGIX',
	'GLX_LARGEST_PBUFFER',
	'GLX_LARGEST_PBUFFER_SGIX',
	'GLX_LEVEL',
	'GLX_MAX_PBUFFER_HEIGHT',
	'GLX_MAX_PBUFFER_HEIGHT_SGIX',
	'GLX_MAX_PBUFFER_PIXELS',
	'GLX_MAX_PBUFFER_PIXELS_SGIX',
	'GLX_MAX_PBUFFER_WIDTH',
	'GLX_MAX_PBUFFER_WIDTH_SGIX',
	'GLX_MIPMAP_TEXTURE_EXT',
	'GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS',
	'GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS',
	'GLX_NONE',
	'GLX_NONE_EXT',
	'GLX_NON_CONFORMANT_CONFIG',
	'GLX_NON_CONFORMANT_VISUAL_EXT',
	'GLX_NO_EXTENSION',
	'GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX',
	'GLX_OPTIMAL_PBUFFER_WIDTH_SGIX',
	'GLX_PBUFFER',
	'GLX_PBUFFER_BIT',
	'GLX_PBUFFER_BIT_SGIX',
	'GLX_PBUFFER_CLOBBER_MASK',
	'GLX_PBUFFER_HEIGHT',
	'GLX_PBUFFER_SGIX',
	'GLX_PBUFFER_WIDTH',
	'GLX_PIPE_RECT_LIMITS_SGIX',
	'GLX_PIPE_RECT_SGIX',
	'GLX_PIXMAP_BIT',
	'GLX_PIXMAP_BIT_SGIX',
	'GLX_PRESERVED_CONTENTS',
	'GLX_PRESERVED_CONTENTS_SGIX',
	'GLX_PSEUDO_COLOR',
	'GLX_PSEUDO_COLOR_EXT',
	'GLX_RED_SIZE',
	'GLX_RENDER_TYPE',
	'GLX_RENDER_TYPE_SGIX',
	'GLX_RGBA',
	'GLX_RGBA_BIT',
	'GLX_RGBA_BIT_SGIX',
	'GLX_RGBA_FLOAT_BIT_ARB',
	'GLX_RGBA_FLOAT_TYPE_ARB',
	'GLX_RGBA_TYPE',
	'GLX_RGBA_TYPE_SGIX',
	'GLX_SAMPLES',
	'GLX_SAMPLES_3DFX',
	'GLX_SAMPLES_ARB',
	'GLX_SAMPLES_SGIS',
	'GLX_SAMPLE_BUFFERS',
	'GLX_SAMPLE_BUFFERS_3DFX',
	'GLX_SAMPLE_BUFFERS_ARB',
	'GLX_SAMPLE_BUFFERS_BIT_SGIX',
	'GLX_SAMPLE_BUFFERS_SGIS',
	'GLX_SAVED',
	'GLX_SAVED_SGIX',
	'GLX_SCREEN',
	'GLX_SCREEN_EXT',
	'GLX_SHARE_CONTEXT_EXT',
	'GLX_SLOW_CONFIG',
	'GLX_SLOW_VISUAL_EXT',
	'GLX_STATIC_COLOR',
	'GLX_STATIC_COLOR_EXT',
	'GLX_STATIC_GRAY',
	'GLX_STATIC_GRAY_EXT',
	'GLX_STENCIL_BUFFER_BIT',
	'GLX_STENCIL_BUFFER_BIT_SGIX',
	'GLX_STENCIL_SIZE',
	'GLX_STEREO',
	'GLX_SWAP_COPY_OML',
	'GLX_SWAP_EXCHANGE_OML',
	'GLX_SWAP_METHOD_OML',
	'GLX_SWAP_UNDEFINED_OML',
	'GLX_SYNC_FRAME_SGIX',
	'GLX_SYNC_SWAP_SGIX',
	'GLX_TEXTURE_1D_BIT_EXT',
	'GLX_TEXTURE_1D_EXT',
	'GLX_TEXTURE_2D_BIT_EXT',
	'GLX_TEXTURE_2D_EXT',
	'GLX_TEXTURE_FORMAT_EXT',
	'GLX_TEXTURE_FORMAT_NONE_EXT',
	'GLX_TEXTURE_FORMAT_RGBA_EXT',
	'GLX_TEXTURE_FORMAT_RGB_EXT',
	'GLX_TEXTURE_RECTANGLE_BIT_EXT',
	'GLX_TEXTURE_RECTANGLE_EXT',
	'GLX_TEXTURE_TARGET_EXT',
	'GLX_TRANSPARENT_ALPHA_VALUE',
	'GLX_TRANSPARENT_ALPHA_VALUE_EXT',
	'GLX_TRANSPARENT_BLUE_VALUE',
	'GLX_TRANSPARENT_BLUE_VALUE_EXT',
	'GLX_TRANSPARENT_GREEN_VALUE',
	'GLX_TRANSPARENT_GREEN_VALUE_EXT',
	'GLX_TRANSPARENT_INDEX',
	'GLX_TRANSPARENT_INDEX_EXT',
	'GLX_TRANSPARENT_INDEX_VALUE',
	'GLX_TRANSPARENT_INDEX_VALUE_EXT',
	'GLX_TRANSPARENT_RED_VALUE',
	'GLX_TRANSPARENT_RED_VALUE_EXT',
	'GLX_TRANSPARENT_RGB',
	'GLX_TRANSPARENT_RGB_EXT',
	'GLX_TRANSPARENT_TYPE',
	'GLX_TRANSPARENT_TYPE_EXT',
	'GLX_TRUE_COLOR',
	'GLX_TRUE_COLOR_EXT',
	'GLX_USE_GL',
	'GLX_VENDOR',
	'GLX_VERSION',
	'GLX_VERSION_1_1',
	'GLX_VERSION_1_2',
	'GLX_VERSION_1_3',
	'GLX_VERSION_1_4',
	'GLX_VISUAL_CAVEAT_EXT',
	'GLX_VISUAL_ID',
	'GLX_VISUAL_ID_EXT',
	'GLX_VISUAL_SELECT_GROUP_SGIX',
	'GLX_WIDTH',
	'GLX_WIDTH_SGIX',
	'GLX_WINDOW',
	'GLX_WINDOW_BIT',
	'GLX_WINDOW_BIT_SGIX',
	'GLX_WINDOW_SGIX',
	'GLX_X_RENDERABLE',
	'GLX_X_RENDERABLE_SGIX',
	'GLX_X_VISUAL_TYPE',
	'GLX_X_VISUAL_TYPE_EXT',
	'GLX_Y_INVERTED_EXT',
	'GL_ALL_CLIENT_ATTRIB_BITS',
	'GL_ALPHA_BLEND_EQUATION_ATI',
	'GL_BYTE',
	'GL_DEBUG_ASSERT_MESA',
	'GL_DEBUG_OBJECT_MESA',
	'GL_DEBUG_PRINT_MESA',
	'GL_DEPTH_STENCIL_MESA',
	'GL_DOUBLE',
	'GL_FALSE',
	'GL_FLOAT',
	'GL_FRAGMENT_PROGRAM_CALLBACK_DATA_MESA',
	'GL_FRAGMENT_PROGRAM_CALLBACK_FUNC_MESA',
	'GL_FRAGMENT_PROGRAM_CALLBACK_MESA',
	'GL_FRAGMENT_PROGRAM_POSITION_MESA',
	'GL_INT',
	'GL_SHORT',
	'GL_TRACE_ALL_BITS_MESA',
	'GL_TRACE_ARRAYS_BIT_MESA',
	'GL_TRACE_ERRORS_BIT_MESA',
	'GL_TRACE_MASK_MESA',
	'GL_TRACE_NAME_MESA',
	'GL_TRACE_OPERATIONS_BIT_MESA',
	'GL_TRACE_PIXELS_BIT_MESA',
	'GL_TRACE_PRIMITIVES_BIT_MESA',
	'GL_TRACE_TEXTURES_BIT_MESA',
	'GL_TRUE',
	'GL_UNSIGNED_BYTE',
	'GL_UNSIGNED_INT',
	'GL_UNSIGNED_INT_24_8_MESA',
	'GL_UNSIGNED_INT_8_24_REV_MESA',
	'GL_UNSIGNED_SHORT',
	'GL_UNSIGNED_SHORT_15_1_MESA',
	'GL_UNSIGNED_SHORT_1_15_REV_MESA',
	'GL_VERTEX_PROGRAM_CALLBACK_DATA_MESA',
	'GL_VERTEX_PROGRAM_CALLBACK_FUNC_MESA',
	'GL_VERTEX_PROGRAM_CALLBACK_MESA',
	'GL_VERTEX_PROGRAM_POSITION_MESA',
	'XCNOENT',
	'XCNOMEM',
	'XCSUCCESS',
	'XK_0',
	'XK_1',
	'XK_2',
	'XK_3',
	'XK_4',
	'XK_5',
	'XK_6',
	'XK_7',
	'XK_8',
	'XK_9',
	'XK_A',
	'XK_AE',
	'XK_B',
	'XK_C',
	'XK_D',
	'XK_E',
	'XK_ENG',
	'XK_ETH',
	'XK_F',
	'XK_F1',
	'XK_F10',
	'XK_F11',
	'XK_F12',
	'XK_F13',
	'XK_F14',
	'XK_F15',
	'XK_F16',
	'XK_F17',
	'XK_F18',
	'XK_F19',
	'XK_F2',
	'XK_F20',
	'XK_F21',
	'XK_F22',
	'XK_F23',
	'XK_F24',
	'XK_F25',
	'XK_F26',
	'XK_F27',
	'XK_F28',
	'XK_F29',
	'XK_F3',
	'XK_F30',
	'XK_F31',
	'XK_F32',
	'XK_F33',
	'XK_F34',
	'XK_F35',
	'XK_F4',
	'XK_F5',
	'XK_F6',
	'XK_F7',
	'XK_F8',
	'XK_F9',
	'XK_G',
	'XK_H',
	'XK_I',
	'XK_J',
	'XK_K',
	'XK_KP_0',
	'XK_KP_1',
	'XK_KP_2',
	'XK_KP_3',
	'XK_KP_4',
	'XK_KP_5',
	'XK_KP_6',
	'XK_KP_7',
	'XK_KP_8',
	'XK_KP_9',
	'XK_KP_F1',
	'XK_KP_F2',
	'XK_KP_F3',
	'XK_KP_F4',
	'XK_L',
	'XK_L1',
	'XK_L10',
	'XK_L2',
	'XK_L3',
	'XK_L4',
	'XK_L5',
	'XK_L6',
	'XK_L7',
	'XK_L8',
	'XK_L9',
	'XK_M',
	'XK_N',
	'XK_O',
	'XK_OE',
	'XK_P',
	'XK_Q',
	'XK_R',
	'XK_R1',
	'XK_R10',
	'XK_R11',
	'XK_R12',
	'XK_R13',
	'XK_R14',
	'XK_R15',
	'XK_R2',
	'XK_R3',
	'XK_R4',
	'XK_R5',
	'XK_R6',
	'XK_R7',
	'XK_R8',
	'XK_R9',
	'XK_S',
	'XK_SCHWA',
	'XK_T',
	'XK_THORN',
	'XK_U',
	'XK_V',
	'XK_W',
	'XK_X',
	'XK_Y',
	'XK_Z',
	'X_HAVE_UTF8_STRING',
	'X_PROTOCOL',
	'X_PROTOCOL_REVISION',
	'_ATFILE_SOURCE',
	'_BITS_PTHREADTYPES_H',
	'_BITS_TYPESIZES_H',
	'_BITS_TYPES_H',
	'_BITS_WCHAR_H',
	'_BSD_SOURCE',
	'_ENDIAN_H',
	'_FEATURES_H',
	'_INTTYPES_H',
	'_ISOC99_SOURCE',
	'_LARGEFILE64_SOURCE',
	'_LARGEFILE_SOURCE',
	'_POSIX_C_SOURCE',
	'_POSIX_SOURCE',
	'_SIGSET_NWORDS',
	'_STDINT_H',
	'_STRUCT_TIMEVAL',
	'_SVID_SOURCE',
	'_SYS_CDEFS_H',
	'_SYS_SELECT_H',
	'_SYS_SYSMACROS_H',
	'_SYS_TYPES_H',
	'_XOPEN_SOURCE',
	'_XOPEN_SOURCE_EXTENDED',
	'__BIG_ENDIAN',
	'__BIT_TYPES_DEFINED__',
	'__FD_SETSIZE',
	'__GLIBC_HAVE_LONG_LONG',
	'__GLIBC_MINOR__',
	'__GLIBC__',
	'__GNU_LIBRARY__',
	'__LITTLE_ENDIAN',
	'__NFDBITS',
	'__PDP_ENDIAN',
	'__PTHREAD_MUTEX_HAVE_PREV',
	'__SIZEOF_PTHREAD_ATTR_T',
	'__SIZEOF_PTHREAD_BARRIERATTR_T',
	'__SIZEOF_PTHREAD_BARRIER_T',
	'__SIZEOF_PTHREAD_CONDATTR_T',
	'__SIZEOF_PTHREAD_COND_T',
	'__SIZEOF_PTHREAD_MUTEXATTR_T',
	'__SIZEOF_PTHREAD_MUTEX_T',
	'__SIZEOF_PTHREAD_RWLOCKATTR_T',
	'__SIZEOF_PTHREAD_RWLOCK_T',
	'__STDC_IEC_559_COMPLEX__',
	'__STDC_IEC_559__',
	'__STDC_ISO_10646__',
	'__USE_ANSI',
	'__USE_ATFILE',
	'__USE_BSD',
	'__USE_FORTIFY_LEVEL',
	'__USE_GNU',
	'__USE_ISOC99',
	'__USE_LARGEFILE',
	'__USE_LARGEFILE64',
	'__USE_MISC',
	'__USE_POSIX',
	'__USE_POSIX199309',
	'__USE_POSIX199506',
	'__USE_POSIX2',
	'__USE_SVID',
	'__USE_UNIX98',
	'__USE_XOPEN',
	'__USE_XOPEN2K',
	'__USE_XOPEN_EXTENDED',
	'__WCHAR_MAX',
	'__WCHAR_MIN',
	'__WORDSIZE',
	'__WORDSIZE_COMPAT32'
]

