'''OpenGL extension IBM.rasterpos_clip

Overview (from the spec)
	
	IBM_rasterpos_clip extends the semantics of the RasterPos functions.  It
	provides an enable that allows a raster position that would normally be
	clipped to be treated as a valid (albeit out-of-viewport) position.
	
	This extension allows applications to specify geometry-aligned pixel
	primitives that may be partially off-screen.  These primitives are
	tested on a pixel-by-pixel basis without being rejected completely
	because of an invalid raster position.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/IBM/rasterpos_clip.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_rasterpos_clip'
GL_RASTER_POSITION_UNCLIPPED_IBM = constant.Constant( 'GL_RASTER_POSITION_UNCLIPPED_IBM', 0x19262 )
glget.addGLGetConstant( GL_RASTER_POSITION_UNCLIPPED_IBM, (1,) )


def glInitRasterposClipIBM():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
