'''OpenGL extension EXT.geometry_shader4

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/geometry_shader4.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_geometry_shader4'
GL_GEOMETRY_SHADER_EXT = constant.Constant( 'GL_GEOMETRY_SHADER_EXT', 0x8DD9 )
GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT', 0x8DDD )
GL_MAX_VERTEX_VARYING_COMPONENTS_EXT = constant.Constant( 'GL_MAX_VERTEX_VARYING_COMPONENTS_EXT', 0x8DDE )
GL_MAX_VARYING_COMPONENTS_EXT = constant.Constant( 'GL_MAX_VARYING_COMPONENTS_EXT', 0x8B4B )
GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT', 0x8DDF )
GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT = constant.Constant( 'GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT', 0x8DE0 )
GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT', 0x8DE1 )
glProgramParameteriEXT = platform.createExtensionFunction( 
	'glProgramParameteriEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, constants.GLint,),
	doc = 'glProgramParameteriEXT( GLuint(program), GLenum(pname), GLint(value) ) -> None',
	argNames = ('program', 'pname', 'value',),
)


def glInitGeometryShader4EXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
