'''OpenGL extension NV.texture_compression_vtc

Overview (from the spec)
	
	This extension adds support for the VTC 3D texture compression
	formats, which are analogous to the S3TC texture compression formats,
	with the addition of some retiling in the Z direction.  VTC has the
	same compression ratio as S3TC and uses 4x4x1, 4x4x2, or 4x4x4
	blocks.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/texture_compression_vtc.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_compression_vtc'



def glInitTextureCompressionVtcNV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
