'''OpenGL extension EXT.blend_subtract

Overview (from the spec)
	
	Two additional blending equations are specified using the interface
	defined by EXT_blend_minmax.  These equations are similar to the
	default blending equation, but produce the difference of its left
	and right hand sides, rather than the sum.  Image differences are
	useful in many image processing applications.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/blend_subtract.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_blend_subtract'
GL_FUNC_SUBTRACT_EXT = constant.Constant( 'GL_FUNC_SUBTRACT_EXT', 0x800A )
GL_FUNC_REVERSE_SUBTRACT_EXT = constant.Constant( 'GL_FUNC_REVERSE_SUBTRACT_EXT', 0x800B )


def glInitBlendSubtractEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
