"""Array-size annotations for OpenGL.raw.GLX

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import GLX as raw

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL import constants as GLconstants
GLvoid = GLconstants.GLvoid

STRING = c_char_p
WSTRING = c_wchar_p


glMultiTexCoord1dvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord1dvARB,
	1,
	arrays.GLdoubleArray,
	'v',
)

glMultiTexCoord1fvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord1fvARB,
	1,
	arrays.GLfloatArray,
	'v',
)

glMultiTexCoord1ivARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord1ivARB,
	1,
	arrays.GLintArray,
	'v',
)

glMultiTexCoord1svARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord1svARB,
	1,
	arrays.GLshortArray,
	'v',
)

glMultiTexCoord2dvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord2dvARB,
	2,
	arrays.GLdoubleArray,
	'v',
)

glMultiTexCoord2fvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord2fvARB,
	2,
	arrays.GLfloatArray,
	'v',
)

glMultiTexCoord2ivARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord2ivARB,
	2,
	arrays.GLintArray,
	'v',
)

glMultiTexCoord2svARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord2svARB,
	2,
	arrays.GLshortArray,
	'v',
)

glMultiTexCoord3dvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord3dvARB,
	3,
	arrays.GLdoubleArray,
	'v',
)

glMultiTexCoord3fvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord3fvARB,
	3,
	arrays.GLfloatArray,
	'v',
)

glMultiTexCoord3ivARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord3ivARB,
	3,
	arrays.GLintArray,
	'v',
)

glMultiTexCoord3svARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord3svARB,
	3,
	arrays.GLshortArray,
	'v',
)

glMultiTexCoord4dvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord4dvARB,
	4,
	arrays.GLdoubleArray,
	'v',
)

glMultiTexCoord4fvARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord4fvARB,
	4,
	arrays.GLfloatArray,
	'v',
)

glMultiTexCoord4ivARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord4ivARB,
	4,
	arrays.GLintArray,
	'v',
)

glMultiTexCoord4svARB = arrays.setInputArraySizeType(
	raw.glMultiTexCoord4svARB,
	4,
	arrays.GLshortArray,
	'v',
)

glXGetProcAddress = arrays.setInputArraySizeType(
	raw.glXGetProcAddress,
	None, # XXX Could not determine size of argument procname for glXGetProcAddress arrays.GLubyteArray
	arrays.GLubyteArray, 
	'procname',
)

__all__ = [
	'glMultiTexCoord1dvARB',
	'glMultiTexCoord1fvARB',
	'glMultiTexCoord1ivARB',
	'glMultiTexCoord1svARB',
	'glMultiTexCoord2dvARB',
	'glMultiTexCoord2fvARB',
	'glMultiTexCoord2ivARB',
	'glMultiTexCoord2svARB',
	'glMultiTexCoord3dvARB',
	'glMultiTexCoord3fvARB',
	'glMultiTexCoord3ivARB',
	'glMultiTexCoord3svARB',
	'glMultiTexCoord4dvARB',
	'glMultiTexCoord4fvARB',
	'glMultiTexCoord4ivARB',
	'glMultiTexCoord4svARB',
	'glXGetProcAddress'
]

