'''OpenGL extension OES.read_format

Overview (from the spec)
	
	This extension provides the capability to query an OpenGL
	implementation for a preferred type and format combination
	for use with reading the color buffer with the ReadPixels
	command.  The purpose is to enable embedded implementations
	to support a greatly reduced set of type/format combinations
	and provide a mechanism for applications to determine which
	implementation-specific combination is supported.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/OES/read_format.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OES_read_format'
GL_IMPLEMENTATION_COLOR_READ_TYPE_OES = constant.Constant( 'GL_IMPLEMENTATION_COLOR_READ_TYPE_OES', 0x8B9A )
GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES = constant.Constant( 'GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES', 0x8B9B )


def glInitReadFormatOES():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
