'''OpenGL extension EXT.draw_buffers2

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/draw_buffers2.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_draw_buffers2'

glColorMaskIndexedEXT = platform.createExtensionFunction( 
	'glColorMaskIndexedEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLboolean, constants.GLboolean, constants.GLboolean, constants.GLboolean,),
	doc = 'glColorMaskIndexedEXT( GLuint(index), GLboolean(r), GLboolean(g), GLboolean(b), GLboolean(a) ) -> None',
	argNames = ('index', 'r', 'g', 'b', 'a',),
)

glGetBooleanIndexedvEXT = platform.createExtensionFunction( 
	'glGetBooleanIndexedvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, ctypes.POINTER(constants.GLboolean),),
	doc = 'glGetBooleanIndexedvEXT( GLenum(target), GLuint(index), POINTER(constants.GLboolean)(data) ) -> None',
	argNames = ('target', 'index', 'data',),
)

glGetIntegerIndexedvEXT = platform.createExtensionFunction( 
	'glGetIntegerIndexedvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLintArray,),
	doc = 'glGetIntegerIndexedvEXT( GLenum(target), GLuint(index), GLintArray(data) ) -> None',
	argNames = ('target', 'index', 'data',),
)

glEnableIndexedEXT = platform.createExtensionFunction( 
	'glEnableIndexedEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint,),
	doc = 'glEnableIndexedEXT( GLenum(target), GLuint(index) ) -> None',
	argNames = ('target', 'index',),
)

glDisableIndexedEXT = platform.createExtensionFunction( 
	'glDisableIndexedEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint,),
	doc = 'glDisableIndexedEXT( GLenum(target), GLuint(index) ) -> None',
	argNames = ('target', 'index',),
)

glIsEnabledIndexedEXT = platform.createExtensionFunction( 
	'glIsEnabledIndexedEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=constants.GLboolean, 
	argTypes=(constants.GLenum, constants.GLuint,),
	doc = 'glIsEnabledIndexedEXT( GLenum(target), GLuint(index) ) -> constants.GLboolean',
	argNames = ('target', 'index',),
)


def glInitDrawBuffers2EXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
