'''OpenGL extension GREMEDY.frame_terminator

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/GREMEDY/frame_terminator.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_GREMEDY_frame_terminator'

glFrameTerminatorGREMEDY = platform.createExtensionFunction( 
	'glFrameTerminatorGREMEDY', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(),
	doc = 'glFrameTerminatorGREMEDY(  ) -> None',
	argNames = (),
)


def glInitFrameTerminatorGREMEDY():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
