'''OpenGL extension DFX.tbuffer

Overview (from the spec)
	
	This extension allows a write mask to be defined for the fragment
	mask which is created during multisample rendering. This can be used
	to create effects such as motion blur and depth of field.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/DFX/tbuffer.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_DFX_tbuffer'

glTbufferMask3DFX = platform.createExtensionFunction( 
	'glTbufferMask3DFX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint,),
	doc = 'glTbufferMask3DFX( GLuint(mask) ) -> None',
	argNames = ('mask',),
)


def glInitTbufferDFX():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
