'''OpenGL extension SGIS.generate_mipmap

Overview (from the spec)
	
	This extension defines a mechanism by which OpenGL can derive the
	entire set of mipmap arrays when provided with only the base level
	array.  Automatic mipmap generation is particularly useful when
	texture images are being provided as a video stream.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SGIS/generate_mipmap.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_generate_mipmap'
GL_GENERATE_MIPMAP_SGIS = constant.Constant( 'GL_GENERATE_MIPMAP_SGIS', 0x8191 )
GL_GENERATE_MIPMAP_HINT_SGIS = constant.Constant( 'GL_GENERATE_MIPMAP_HINT_SGIS', 0x8192 )
glget.addGLGetConstant( GL_GENERATE_MIPMAP_HINT_SGIS, (1,) )


def glInitGenerateMipmapSGIS():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
