'''OpenGL extension EXT.shadow_funcs

Overview (from the spec)
	
	This extension generalizes the GL_ARB_shadow extension to support all
	eight binary texture comparison functions rather than just GL_LEQUAL
	and GL_GEQUAL.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/shadow_funcs.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_shadow_funcs'



def glInitShadowFuncsEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
