'''OpenGL extension SGIX.async_histogram

Overview (from the spec)
	
	This extension introduces a new asynchronous mode for histogram
	and minmax readbacks.  It allows programs to get the contents of a
	histogram or minmax table without blocking and to continue issuing
	graphics commands during the readback.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SGIX/async_histogram.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_async_histogram'
GL_ASYNC_HISTOGRAM_SGIX = constant.Constant( 'GL_ASYNC_HISTOGRAM_SGIX', 0x832C )
glget.addGLGetConstant( GL_ASYNC_HISTOGRAM_SGIX, (1,) )
GL_MAX_ASYNC_HISTOGRAM_SGIX = constant.Constant( 'GL_MAX_ASYNC_HISTOGRAM_SGIX', 0x832D )
glget.addGLGetConstant( GL_MAX_ASYNC_HISTOGRAM_SGIX, (1,) )


def glInitAsyncHistogramSGIX():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
