# -*- coding: iso-8859-1 -*-
"""Raw (C-style) API for OpenGL.GLUT

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw.GLUT.constants import *

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL import constants as GLconstants
GLvoid = GLconstants.GLvoid

FUNCTION_TYPE = platform.PLATFORM.functionTypeFor( platform.GLUT )

STRING = c_char_p
from OpenGL.constants import GLenum
from OpenGL.constants import GLfloat
from OpenGL.constants import GLdouble
from OpenGL.constants import GLint




# /usr/include/GL/freeglut_std.h 445
glutAddMenuEntry = platform.createBaseFunction( 
	'glutAddMenuEntry', dll=platform.GLUT, resultType=None, 
	argTypes=[STRING,c_int],
	doc='glutAddMenuEntry( STRING(label), c_int(value) ) -> None', 
	argNames=('label', 'value'),
)


# /usr/include/GL/freeglut_std.h 446
glutAddSubMenu = platform.createBaseFunction( 
	'glutAddSubMenu', dll=platform.GLUT, resultType=None, 
	argTypes=[STRING,c_int],
	doc='glutAddSubMenu( STRING(label), c_int(subMenu) ) -> None', 
	argNames=('label', 'subMenu'),
)


# /usr/include/GL/freeglut_std.h 450
glutAttachMenu = platform.createBaseFunction( 
	'glutAttachMenu', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutAttachMenu( c_int(button) ) -> None', 
	argNames=('button',),
)


# /usr/include/GL/freeglut_std.h 499
glutBitmapCharacter = platform.createBaseFunction( 
	'glutBitmapCharacter', dll=platform.GLUT, resultType=None, 
	argTypes=[c_void_p,c_int],
	doc='glutBitmapCharacter( c_void_p(font), c_int(character) ) -> None', 
	argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 503
glutBitmapLength = platform.createBaseFunction( 
	'glutBitmapLength', dll=platform.GLUT, resultType=c_int, 
	argTypes=[c_void_p,POINTER(c_ubyte)],
	doc='glutBitmapLength( c_void_p(font), POINTER(c_ubyte)(string) ) -> c_int', 
	argNames=('font', 'string'),
)


# /usr/include/GL/freeglut_std.h 500
glutBitmapWidth = platform.createBaseFunction( 
	'glutBitmapWidth', dll=platform.GLUT, resultType=c_int, 
	argTypes=[c_void_p,c_int],
	doc='glutBitmapWidth( c_void_p(font), c_int(character) ) -> c_int', 
	argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 483
glutButtonBoxFunc = platform.createBaseFunction( 
	'glutButtonBoxFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutButtonBoxFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 447
glutChangeToMenuEntry = platform.createBaseFunction( 
	'glutChangeToMenuEntry', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,STRING,c_int],
	doc='glutChangeToMenuEntry( c_int(item), STRING(label), c_int(value) ) -> None', 
	argNames=('item', 'label', 'value'),
)


# /usr/include/GL/freeglut_std.h 448
glutChangeToSubMenu = platform.createBaseFunction( 
	'glutChangeToSubMenu', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,STRING,c_int],
	doc='glutChangeToSubMenu( c_int(item), STRING(label), c_int(value) ) -> None', 
	argNames=('item', 'label', 'value'),
)


# /usr/include/GL/freeglut_std.h 555
glutCopyColormap = platform.createBaseFunction( 
	'glutCopyColormap', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutCopyColormap( c_int(window) ) -> None', 
	argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 441
glutCreateMenu = platform.createBaseFunction( 
	'glutCreateMenu', dll=platform.GLUT, resultType=c_int, 
	argTypes=[FUNCTION_TYPE(c_int, c_int)],
	doc='glutCreateMenu( FUNCTION_TYPE(c_int, c_int)(callback) ) -> c_int', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 399
glutCreateSubWindow = platform.createBaseFunction( 
	'glutCreateSubWindow', dll=platform.GLUT, resultType=c_int, 
	argTypes=[c_int,c_int,c_int,c_int,c_int],
	doc='glutCreateSubWindow( c_int(window), c_int(x), c_int(y), c_int(width), c_int(height) ) -> c_int', 
	argNames=('window', 'x', 'y', 'width', 'height'),
)


# /usr/include/GL/freeglut_std.h 398
glutCreateWindow = platform.createBaseFunction( 
	'glutCreateWindow', dll=platform.GLUT, resultType=c_int, 
	argTypes=[STRING],
	doc='glutCreateWindow( STRING(title) ) -> c_int', 
	argNames=('title',),
)


# /usr/include/GL/freeglut_std.h 442
glutDestroyMenu = platform.createBaseFunction( 
	'glutDestroyMenu', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutDestroyMenu( c_int(menu) ) -> None', 
	argNames=('menu',),
)


# /usr/include/GL/freeglut_std.h 400
glutDestroyWindow = platform.createBaseFunction( 
	'glutDestroyWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutDestroyWindow( c_int(window) ) -> None', 
	argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 451
glutDetachMenu = platform.createBaseFunction( 
	'glutDetachMenu', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutDetachMenu( c_int(button) ) -> None', 
	argNames=('button',),
)


# /usr/include/GL/freeglut_std.h 492
glutDeviceGet = platform.createBaseFunction( 
	'glutDeviceGet', dll=platform.GLUT, resultType=c_int, 
	argTypes=[GLenum],
	doc='glutDeviceGet( GLenum(query) ) -> c_int', 
	argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 484
glutDialsFunc = platform.createBaseFunction( 
	'glutDialsFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutDialsFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 466
glutDisplayFunc = platform.createBaseFunction( 
	'glutDisplayFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None)],
	doc='glutDisplayFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 537
glutEnterGameMode = platform.createBaseFunction( 
	'glutEnterGameMode', dll=platform.GLUT, resultType=c_int, 
	argTypes=[],
	doc='glutEnterGameMode(  ) -> c_int', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 470
glutEntryFunc = platform.createBaseFunction( 
	'glutEntryFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int)],
	doc='glutEntryFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 430
glutEstablishOverlay = platform.createBaseFunction( 
	'glutEstablishOverlay', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutEstablishOverlay(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 567
glutExtensionSupported = platform.createBaseFunction( 
	'glutExtensionSupported', dll=platform.GLUT, resultType=c_int, 
	argTypes=[STRING],
	doc='glutExtensionSupported( STRING(extension) ) -> c_int', 
	argNames=('extension',),
)


# /usr/include/GL/freeglut_std.h 562
glutForceJoystickFunc = platform.createBaseFunction( 
	'glutForceJoystickFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutForceJoystickFunc(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 412
glutFullScreen = platform.createBaseFunction( 
	'glutFullScreen', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutFullScreen(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 539
glutGameModeGet = platform.createBaseFunction( 
	'glutGameModeGet', dll=platform.GLUT, resultType=c_int, 
	argTypes=[GLenum],
	doc='glutGameModeGet( GLenum(query) ) -> c_int', 
	argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 536
glutGameModeString = platform.createBaseFunction( 
	'glutGameModeString', dll=platform.GLUT, resultType=None, 
	argTypes=[STRING],
	doc='glutGameModeString( STRING(string) ) -> None', 
	argNames=('string',),
)


# /usr/include/GL/freeglut_std.h 491
glutGet = platform.createBaseFunction( 
	'glutGet', dll=platform.GLUT, resultType=c_int, 
	argTypes=[GLenum],
	doc='glutGet( GLenum(query) ) -> c_int', 
	argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 554
glutGetColor = platform.createBaseFunction( 
	'glutGetColor', dll=platform.GLUT, resultType=GLfloat, 
	argTypes=[c_int,c_int],
	doc='glutGetColor( c_int(color), c_int(component) ) -> GLfloat', 
	argNames=('color', 'component'),
)


# /usr/include/GL/freeglut_std.h 443
glutGetMenu = platform.createBaseFunction( 
	'glutGetMenu', dll=platform.GLUT, resultType=c_int, 
	argTypes=[],
	doc='glutGetMenu(  ) -> c_int', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 493
glutGetModifiers = platform.createBaseFunction( 
	'glutGetModifiers', dll=platform.GLUT, resultType=c_int, 
	argTypes=[],
	doc='glutGetModifiers(  ) -> c_int', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 402
glutGetWindow = platform.createBaseFunction( 
	'glutGetWindow', dll=platform.GLUT, resultType=c_int, 
	argTypes=[],
	doc='glutGetWindow(  ) -> c_int', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 436
glutHideOverlay = platform.createBaseFunction( 
	'glutHideOverlay', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutHideOverlay(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 408
glutHideWindow = platform.createBaseFunction( 
	'glutHideWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutHideWindow(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 409
glutIconifyWindow = platform.createBaseFunction( 
	'glutIconifyWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutIconifyWindow(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 457
glutIdleFunc = platform.createBaseFunction( 
	'glutIdleFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None)],
	doc='glutIdleFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 560
glutIgnoreKeyRepeat = platform.createBaseFunction( 
	'glutIgnoreKeyRepeat', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutIgnoreKeyRepeat( c_int(ignore) ) -> None', 
	argNames=('ignore',),
)


# /usr/include/GL/freeglut_std.h 384
glutInit = platform.createBaseFunction( 
	'glutInit', dll=platform.GLUT, resultType=None, 
	argTypes=[POINTER(c_int),POINTER(STRING)],
	doc='glutInit( POINTER(c_int)(pargc), POINTER(STRING)(argv) ) -> None', 
	argNames=('pargc', 'argv'),
)


# /usr/include/GL/freeglut_std.h 387
glutInitDisplayMode = platform.createBaseFunction( 
	'glutInitDisplayMode', dll=platform.GLUT, resultType=None, 
	argTypes=[c_uint],
	doc='glutInitDisplayMode( c_uint(displayMode) ) -> None', 
	argNames=('displayMode',),
)


# /usr/include/GL/freeglut_std.h 388
glutInitDisplayString = platform.createBaseFunction( 
	'glutInitDisplayString', dll=platform.GLUT, resultType=None, 
	argTypes=[STRING],
	doc='glutInitDisplayString( STRING(displayMode) ) -> None', 
	argNames=('displayMode',),
)


# /usr/include/GL/freeglut_std.h 385
glutInitWindowPosition = platform.createBaseFunction( 
	'glutInitWindowPosition', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int],
	doc='glutInitWindowPosition( c_int(x), c_int(y) ) -> None', 
	argNames=('x', 'y'),
)


# /usr/include/GL/freeglut_std.h 386
glutInitWindowSize = platform.createBaseFunction( 
	'glutInitWindowSize', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int],
	doc='glutInitWindowSize( c_int(width), c_int(height) ) -> None', 
	argNames=('width', 'height'),
)


# /usr/include/GL/freeglut_std.h 474
glutJoystickFunc = platform.createBaseFunction( 
	'glutJoystickFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_uint, c_int, c_int, c_int),c_int],
	doc='glutJoystickFunc( FUNCTION_TYPE(None, c_uint, c_int, c_int, c_int)(callback), c_int(pollInterval) ) -> None', 
	argNames=('callback', 'pollInterval'),
)


# /usr/include/GL/freeglut_std.h 462
glutKeyboardFunc = platform.createBaseFunction( 
	'glutKeyboardFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_ubyte, c_int, c_int)],
	doc='glutKeyboardFunc( FUNCTION_TYPE(None, c_ubyte, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 472
glutKeyboardUpFunc = platform.createBaseFunction( 
	'glutKeyboardUpFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_ubyte, c_int, c_int)],
	doc='glutKeyboardUpFunc( FUNCTION_TYPE(None, c_ubyte, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 494
glutLayerGet = platform.createBaseFunction( 
	'glutLayerGet', dll=platform.GLUT, resultType=c_int, 
	argTypes=[GLenum],
	doc='glutLayerGet( GLenum(query) ) -> c_int', 
	argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 538
glutLeaveGameMode = platform.createBaseFunction( 
	'glutLeaveGameMode', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutLeaveGameMode(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 393
glutMainLoop = platform.createBaseFunction( 
	'glutMainLoop', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutMainLoop(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 475
glutMenuStateFunc = platform.createBaseFunction( 
	'glutMenuStateFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int)],
	doc='glutMenuStateFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 476
glutMenuStatusFunc = platform.createBaseFunction( 
	'glutMenuStatusFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int)],
	doc='glutMenuStatusFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 468
glutMotionFunc = platform.createBaseFunction( 
	'glutMotionFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutMotionFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 467
glutMouseFunc = platform.createBaseFunction( 
	'glutMouseFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)],
	doc='glutMouseFunc( FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 477
glutOverlayDisplayFunc = platform.createBaseFunction( 
	'glutOverlayDisplayFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None)],
	doc='glutOverlayDisplayFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 469
glutPassiveMotionFunc = platform.createBaseFunction( 
	'glutPassiveMotionFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutPassiveMotionFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 411
glutPopWindow = platform.createBaseFunction( 
	'glutPopWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutPopWindow(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 406
glutPositionWindow = platform.createBaseFunction( 
	'glutPositionWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int],
	doc='glutPositionWindow( c_int(x), c_int(y) ) -> None', 
	argNames=('x', 'y'),
)


# /usr/include/GL/freeglut_std.h 433
glutPostOverlayRedisplay = platform.createBaseFunction( 
	'glutPostOverlayRedisplay', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutPostOverlayRedisplay(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 418
glutPostRedisplay = platform.createBaseFunction( 
	'glutPostRedisplay', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutPostRedisplay(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 434
glutPostWindowOverlayRedisplay = platform.createBaseFunction( 
	'glutPostWindowOverlayRedisplay', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutPostWindowOverlayRedisplay( c_int(window) ) -> None', 
	argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 417
glutPostWindowRedisplay = platform.createBaseFunction( 
	'glutPostWindowRedisplay', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutPostWindowRedisplay( c_int(window) ) -> None', 
	argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 410
glutPushWindow = platform.createBaseFunction( 
	'glutPushWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutPushWindow(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 449
glutRemoveMenuItem = platform.createBaseFunction( 
	'glutRemoveMenuItem', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutRemoveMenuItem( c_int(item) ) -> None', 
	argNames=('item',),
)


# /usr/include/GL/freeglut_std.h 431
glutRemoveOverlay = platform.createBaseFunction( 
	'glutRemoveOverlay', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutRemoveOverlay(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 568
glutReportErrors = platform.createBaseFunction( 
	'glutReportErrors', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutReportErrors(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 464
glutReshapeFunc = platform.createBaseFunction( 
	'glutReshapeFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutReshapeFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 405
glutReshapeWindow = platform.createBaseFunction( 
	'glutReshapeWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int],
	doc='glutReshapeWindow( c_int(width), c_int(height) ) -> None', 
	argNames=('width', 'height'),
)


# /usr/include/GL/freeglut_std.h 553
glutSetColor = platform.createBaseFunction( 
	'glutSetColor', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,GLfloat,GLfloat,GLfloat],
	doc='glutSetColor( c_int(color), GLfloat(red), GLfloat(green), GLfloat(blue) ) -> None', 
	argNames=('color', 'red', 'green', 'blue'),
)


# /usr/include/GL/freeglut_std.h 425
glutSetCursor = platform.createBaseFunction( 
	'glutSetCursor', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutSetCursor( c_int(cursor) ) -> None', 
	argNames=('cursor',),
)


# /usr/include/GL/freeglut_std.h 404
glutSetIconTitle = platform.createBaseFunction( 
	'glutSetIconTitle', dll=platform.GLUT, resultType=None, 
	argTypes=[STRING],
	doc='glutSetIconTitle( STRING(title) ) -> None', 
	argNames=('title',),
)


# /usr/include/GL/freeglut_std.h 561
glutSetKeyRepeat = platform.createBaseFunction( 
	'glutSetKeyRepeat', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutSetKeyRepeat( c_int(repeatMode) ) -> None', 
	argNames=('repeatMode',),
)


# /usr/include/GL/freeglut_std.h 444
glutSetMenu = platform.createBaseFunction( 
	'glutSetMenu', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutSetMenu( c_int(menu) ) -> None', 
	argNames=('menu',),
)


# /usr/include/GL/freeglut_std.h 401
glutSetWindow = platform.createBaseFunction( 
	'glutSetWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int],
	doc='glutSetWindow( c_int(window) ) -> None', 
	argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 403
glutSetWindowTitle = platform.createBaseFunction( 
	'glutSetWindowTitle', dll=platform.GLUT, resultType=None, 
	argTypes=[STRING],
	doc='glutSetWindowTitle( STRING(title) ) -> None', 
	argNames=('title',),
)


# /usr/include/GL/freeglut_std.h 545
glutSetupVideoResizing = platform.createBaseFunction( 
	'glutSetupVideoResizing', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutSetupVideoResizing(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 435
glutShowOverlay = platform.createBaseFunction( 
	'glutShowOverlay', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutShowOverlay(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 407
glutShowWindow = platform.createBaseFunction( 
	'glutShowWindow', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutShowWindow(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 514
glutSolidCone = platform.createBaseFunction( 
	'glutSolidCone', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble,GLdouble,GLint,GLint],
	doc='glutSolidCone( GLdouble(base), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
	argNames=('base', 'height', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 510
glutSolidCube = platform.createBaseFunction( 
	'glutSolidCube', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble],
	doc='glutSolidCube( GLdouble(size) ) -> None', 
	argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 519
glutSolidDodecahedron = platform.createBaseFunction( 
	'glutSolidDodecahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutSolidDodecahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 525
glutSolidIcosahedron = platform.createBaseFunction( 
	'glutSolidIcosahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutSolidIcosahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 521
glutSolidOctahedron = platform.createBaseFunction( 
	'glutSolidOctahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutSolidOctahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 512
glutSolidSphere = platform.createBaseFunction( 
	'glutSolidSphere', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble,GLint,GLint],
	doc='glutSolidSphere( GLdouble(radius), GLint(slices), GLint(stacks) ) -> None', 
	argNames=('radius', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 531
glutSolidTeapot = platform.createBaseFunction( 
	'glutSolidTeapot', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble],
	doc='glutSolidTeapot( GLdouble(size) ) -> None', 
	argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 523
glutSolidTetrahedron = platform.createBaseFunction( 
	'glutSolidTetrahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutSolidTetrahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 517
glutSolidTorus = platform.createBaseFunction( 
	'glutSolidTorus', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble,GLdouble,GLint,GLint],
	doc='glutSolidTorus( GLdouble(innerRadius), GLdouble(outerRadius), GLint(sides), GLint(rings) ) -> None', 
	argNames=('innerRadius', 'outerRadius', 'sides', 'rings'),
)


# /usr/include/GL/freeglut_std.h 482
glutSpaceballButtonFunc = platform.createBaseFunction( 
	'glutSpaceballButtonFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutSpaceballButtonFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 480
glutSpaceballMotionFunc = platform.createBaseFunction( 
	'glutSpaceballMotionFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int)],
	doc='glutSpaceballMotionFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 481
glutSpaceballRotateFunc = platform.createBaseFunction( 
	'glutSpaceballRotateFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int)],
	doc='glutSpaceballRotateFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 463
glutSpecialFunc = platform.createBaseFunction( 
	'glutSpecialFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int)],
	doc='glutSpecialFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 473
glutSpecialUpFunc = platform.createBaseFunction( 
	'glutSpecialUpFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int)],
	doc='glutSpecialUpFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 546
glutStopVideoResizing = platform.createBaseFunction( 
	'glutStopVideoResizing', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutStopVideoResizing(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 501
glutStrokeCharacter = platform.createBaseFunction( 
	'glutStrokeCharacter', dll=platform.GLUT, resultType=None, 
	argTypes=[c_void_p,c_int],
	doc='glutStrokeCharacter( c_void_p(font), c_int(character) ) -> None', 
	argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 504
glutStrokeLength = platform.createBaseFunction( 
	'glutStrokeLength', dll=platform.GLUT, resultType=c_int, 
	argTypes=[c_void_p,POINTER(c_ubyte)],
	doc='glutStrokeLength( c_void_p(font), POINTER(c_ubyte)(string) ) -> c_int', 
	argNames=('font', 'string'),
)


# /usr/include/GL/freeglut_std.h 502
glutStrokeWidth = platform.createBaseFunction( 
	'glutStrokeWidth', dll=platform.GLUT, resultType=c_int, 
	argTypes=[c_void_p,c_int],
	doc='glutStrokeWidth( c_void_p(font), c_int(character) ) -> c_int', 
	argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 419
glutSwapBuffers = platform.createBaseFunction( 
	'glutSwapBuffers', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutSwapBuffers(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 486
glutTabletButtonFunc = platform.createBaseFunction( 
	'glutTabletButtonFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)],
	doc='glutTabletButtonFunc( FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 485
glutTabletMotionFunc = platform.createBaseFunction( 
	'glutTabletMotionFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int, c_int)],
	doc='glutTabletMotionFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 456
glutTimerFunc = platform.createBaseFunction( 
	'glutTimerFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[c_uint,FUNCTION_TYPE(None, c_int),c_int],
	doc='glutTimerFunc( c_uint(time), FUNCTION_TYPE(None, c_int)(callback), c_int(value) ) -> None', 
	argNames=('time', 'callback', 'value'),
)


# /usr/include/GL/freeglut_std.h 432
glutUseLayer = platform.createBaseFunction( 
	'glutUseLayer', dll=platform.GLUT, resultType=None, 
	argTypes=[GLenum],
	doc='glutUseLayer( GLenum(layer) ) -> None', 
	argNames=('layer',),
)


# /usr/include/GL/freeglut_std.h 548
glutVideoPan = platform.createBaseFunction( 
	'glutVideoPan', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int,c_int,c_int],
	doc='glutVideoPan( c_int(x), c_int(y), c_int(width), c_int(height) ) -> None', 
	argNames=('x', 'y', 'width', 'height'),
)


# /usr/include/GL/freeglut_std.h 547
glutVideoResize = platform.createBaseFunction( 
	'glutVideoResize', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int,c_int,c_int],
	doc='glutVideoResize( c_int(x), c_int(y), c_int(width), c_int(height) ) -> None', 
	argNames=('x', 'y', 'width', 'height'),
)


# /usr/include/GL/freeglut_std.h 544
glutVideoResizeGet = platform.createBaseFunction( 
	'glutVideoResizeGet', dll=platform.GLUT, resultType=c_int, 
	argTypes=[GLenum],
	doc='glutVideoResizeGet( GLenum(query) ) -> c_int', 
	argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 465
glutVisibilityFunc = platform.createBaseFunction( 
	'glutVisibilityFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int)],
	doc='glutVisibilityFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 424
glutWarpPointer = platform.createBaseFunction( 
	'glutWarpPointer', dll=platform.GLUT, resultType=None, 
	argTypes=[c_int,c_int],
	doc='glutWarpPointer( c_int(x), c_int(y) ) -> None', 
	argNames=('x', 'y'),
)


# /usr/include/GL/freeglut_std.h 478
glutWindowStatusFunc = platform.createBaseFunction( 
	'glutWindowStatusFunc', dll=platform.GLUT, resultType=None, 
	argTypes=[FUNCTION_TYPE(None, c_int)],
	doc='glutWindowStatusFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
	argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 513
glutWireCone = platform.createBaseFunction( 
	'glutWireCone', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble,GLdouble,GLint,GLint],
	doc='glutWireCone( GLdouble(base), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
	argNames=('base', 'height', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 509
glutWireCube = platform.createBaseFunction( 
	'glutWireCube', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble],
	doc='glutWireCube( GLdouble(size) ) -> None', 
	argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 518
glutWireDodecahedron = platform.createBaseFunction( 
	'glutWireDodecahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutWireDodecahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 524
glutWireIcosahedron = platform.createBaseFunction( 
	'glutWireIcosahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutWireIcosahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 520
glutWireOctahedron = platform.createBaseFunction( 
	'glutWireOctahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutWireOctahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 511
glutWireSphere = platform.createBaseFunction( 
	'glutWireSphere', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble,GLint,GLint],
	doc='glutWireSphere( GLdouble(radius), GLint(slices), GLint(stacks) ) -> None', 
	argNames=('radius', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 530
glutWireTeapot = platform.createBaseFunction( 
	'glutWireTeapot', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble],
	doc='glutWireTeapot( GLdouble(size) ) -> None', 
	argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 522
glutWireTetrahedron = platform.createBaseFunction( 
	'glutWireTetrahedron', dll=platform.GLUT, resultType=None, 
	argTypes=[],
	doc='glutWireTetrahedron(  ) -> None', 
	argNames=(),
)


# /usr/include/GL/freeglut_std.h 516
glutWireTorus = platform.createBaseFunction( 
	'glutWireTorus', dll=platform.GLUT, resultType=None, 
	argTypes=[GLdouble,GLdouble,GLint,GLint],
	doc='glutWireTorus( GLdouble(innerRadius), GLdouble(outerRadius), GLint(sides), GLint(rings) ) -> None', 
	argNames=('innerRadius', 'outerRadius', 'sides', 'rings'),
)

__all__ = [
	'GLUT_ACCUM',
	'GLUT_ACTIVE_ALT',
	'GLUT_ACTIVE_CTRL',
	'GLUT_ACTIVE_SHIFT',
	'GLUT_ALPHA',
	'GLUT_API_VERSION',
	'GLUT_BLUE',
	'GLUT_CURSOR_BOTTOM_LEFT_CORNER',
	'GLUT_CURSOR_BOTTOM_RIGHT_CORNER',
	'GLUT_CURSOR_BOTTOM_SIDE',
	'GLUT_CURSOR_CROSSHAIR',
	'GLUT_CURSOR_CYCLE',
	'GLUT_CURSOR_DESTROY',
	'GLUT_CURSOR_FULL_CROSSHAIR',
	'GLUT_CURSOR_HELP',
	'GLUT_CURSOR_INFO',
	'GLUT_CURSOR_INHERIT',
	'GLUT_CURSOR_LEFT_ARROW',
	'GLUT_CURSOR_LEFT_RIGHT',
	'GLUT_CURSOR_LEFT_SIDE',
	'GLUT_CURSOR_NONE',
	'GLUT_CURSOR_RIGHT_ARROW',
	'GLUT_CURSOR_RIGHT_SIDE',
	'GLUT_CURSOR_SPRAY',
	'GLUT_CURSOR_TEXT',
	'GLUT_CURSOR_TOP_LEFT_CORNER',
	'GLUT_CURSOR_TOP_RIGHT_CORNER',
	'GLUT_CURSOR_TOP_SIDE',
	'GLUT_CURSOR_UP_DOWN',
	'GLUT_CURSOR_WAIT',
	'GLUT_DEPTH',
	'GLUT_DEVICE_IGNORE_KEY_REPEAT',
	'GLUT_DEVICE_KEY_REPEAT',
	'GLUT_DISPLAY_MODE_POSSIBLE',
	'GLUT_DOUBLE',
	'GLUT_DOWN',
	'GLUT_ELAPSED_TIME',
	'GLUT_ENTERED',
	'GLUT_FULLY_COVERED',
	'GLUT_FULLY_RETAINED',
	'GLUT_GAME_MODE_ACTIVE',
	'GLUT_GAME_MODE_DISPLAY_CHANGED',
	'GLUT_GAME_MODE_HEIGHT',
	'GLUT_GAME_MODE_PIXEL_DEPTH',
	'GLUT_GAME_MODE_POSSIBLE',
	'GLUT_GAME_MODE_REFRESH_RATE',
	'GLUT_GAME_MODE_WIDTH',
	'GLUT_GREEN',
	'GLUT_HAS_DIAL_AND_BUTTON_BOX',
	'GLUT_HAS_JOYSTICK',
	'GLUT_HAS_KEYBOARD',
	'GLUT_HAS_MOUSE',
	'GLUT_HAS_OVERLAY',
	'GLUT_HAS_SPACEBALL',
	'GLUT_HAS_TABLET',
	'GLUT_HIDDEN',
	'GLUT_INDEX',
	'GLUT_INIT_DISPLAY_MODE',
	'GLUT_INIT_STATE',
	'GLUT_INIT_WINDOW_HEIGHT',
	'GLUT_INIT_WINDOW_WIDTH',
	'GLUT_INIT_WINDOW_X',
	'GLUT_INIT_WINDOW_Y',
	'GLUT_JOYSTICK_AXES',
	'GLUT_JOYSTICK_BUTTONS',
	'GLUT_JOYSTICK_BUTTON_A',
	'GLUT_JOYSTICK_BUTTON_B',
	'GLUT_JOYSTICK_BUTTON_C',
	'GLUT_JOYSTICK_BUTTON_D',
	'GLUT_JOYSTICK_POLL_RATE',
	'GLUT_KEY_DOWN',
	'GLUT_KEY_END',
	'GLUT_KEY_F1',
	'GLUT_KEY_F10',
	'GLUT_KEY_F11',
	'GLUT_KEY_F12',
	'GLUT_KEY_F2',
	'GLUT_KEY_F3',
	'GLUT_KEY_F4',
	'GLUT_KEY_F5',
	'GLUT_KEY_F6',
	'GLUT_KEY_F7',
	'GLUT_KEY_F8',
	'GLUT_KEY_F9',
	'GLUT_KEY_HOME',
	'GLUT_KEY_INSERT',
	'GLUT_KEY_LEFT',
	'GLUT_KEY_PAGE_DOWN',
	'GLUT_KEY_PAGE_UP',
	'GLUT_KEY_REPEAT_DEFAULT',
	'GLUT_KEY_REPEAT_OFF',
	'GLUT_KEY_REPEAT_ON',
	'GLUT_KEY_RIGHT',
	'GLUT_KEY_UP',
	'GLUT_LAYER_IN_USE',
	'GLUT_LEFT',
	'GLUT_LEFT_BUTTON',
	'GLUT_LUMINANCE',
	'GLUT_MENU_IN_USE',
	'GLUT_MENU_NOT_IN_USE',
	'GLUT_MENU_NUM_ITEMS',
	'GLUT_MIDDLE_BUTTON',
	'GLUT_MULTISAMPLE',
	'GLUT_NORMAL',
	'GLUT_NORMAL_DAMAGED',
	'GLUT_NOT_VISIBLE',
	'GLUT_NUM_BUTTON_BOX_BUTTONS',
	'GLUT_NUM_DIALS',
	'GLUT_NUM_MOUSE_BUTTONS',
	'GLUT_NUM_SPACEBALL_BUTTONS',
	'GLUT_NUM_TABLET_BUTTONS',
	'GLUT_OVERLAY',
	'GLUT_OVERLAY_DAMAGED',
	'GLUT_OVERLAY_POSSIBLE',
	'GLUT_OWNS_JOYSTICK',
	'GLUT_PARTIALLY_RETAINED',
	'GLUT_RED',
	'GLUT_RGB',
	'GLUT_RGBA',
	'GLUT_RIGHT_BUTTON',
	'GLUT_SCREEN_HEIGHT',
	'GLUT_SCREEN_HEIGHT_MM',
	'GLUT_SCREEN_WIDTH',
	'GLUT_SCREEN_WIDTH_MM',
	'GLUT_SINGLE',
	'GLUT_STENCIL',
	'GLUT_STEREO',
	'GLUT_TRANSPARENT_INDEX',
	'GLUT_UP',
	'GLUT_VIDEO_RESIZE_HEIGHT',
	'GLUT_VIDEO_RESIZE_HEIGHT_DELTA',
	'GLUT_VIDEO_RESIZE_IN_USE',
	'GLUT_VIDEO_RESIZE_POSSIBLE',
	'GLUT_VIDEO_RESIZE_WIDTH',
	'GLUT_VIDEO_RESIZE_WIDTH_DELTA',
	'GLUT_VIDEO_RESIZE_X',
	'GLUT_VIDEO_RESIZE_X_DELTA',
	'GLUT_VIDEO_RESIZE_Y',
	'GLUT_VIDEO_RESIZE_Y_DELTA',
	'GLUT_VISIBLE',
	'GLUT_WINDOW_ACCUM_ALPHA_SIZE',
	'GLUT_WINDOW_ACCUM_BLUE_SIZE',
	'GLUT_WINDOW_ACCUM_GREEN_SIZE',
	'GLUT_WINDOW_ACCUM_RED_SIZE',
	'GLUT_WINDOW_ALPHA_SIZE',
	'GLUT_WINDOW_BLUE_SIZE',
	'GLUT_WINDOW_BUFFER_SIZE',
	'GLUT_WINDOW_COLORMAP_SIZE',
	'GLUT_WINDOW_CURSOR',
	'GLUT_WINDOW_DEPTH_SIZE',
	'GLUT_WINDOW_DOUBLEBUFFER',
	'GLUT_WINDOW_FORMAT_ID',
	'GLUT_WINDOW_GREEN_SIZE',
	'GLUT_WINDOW_HEIGHT',
	'GLUT_WINDOW_NUM_CHILDREN',
	'GLUT_WINDOW_NUM_SAMPLES',
	'GLUT_WINDOW_PARENT',
	'GLUT_WINDOW_RED_SIZE',
	'GLUT_WINDOW_RGBA',
	'GLUT_WINDOW_STENCIL_SIZE',
	'GLUT_WINDOW_STEREO',
	'GLUT_WINDOW_WIDTH',
	'GLUT_WINDOW_X',
	'GLUT_WINDOW_Y',
	'GLUT_XLIB_IMPLEMENTATION',
	'GLdouble',
	'GLenum',
	'GLfloat',
	'GLint',
	'glutAddMenuEntry',
	'glutAddSubMenu',
	'glutAttachMenu',
	'glutBitmapCharacter',
	'glutBitmapLength',
	'glutBitmapWidth',
	'glutButtonBoxFunc',
	'glutChangeToMenuEntry',
	'glutChangeToSubMenu',
	'glutCopyColormap',
	'glutCreateMenu',
	'glutCreateSubWindow',
	'glutCreateWindow',
	'glutDestroyMenu',
	'glutDestroyWindow',
	'glutDetachMenu',
	'glutDeviceGet',
	'glutDialsFunc',
	'glutDisplayFunc',
	'glutEnterGameMode',
	'glutEntryFunc',
	'glutEstablishOverlay',
	'glutExtensionSupported',
	'glutForceJoystickFunc',
	'glutFullScreen',
	'glutGameModeGet',
	'glutGameModeString',
	'glutGet',
	'glutGetColor',
	'glutGetMenu',
	'glutGetModifiers',
	'glutGetWindow',
	'glutHideOverlay',
	'glutHideWindow',
	'glutIconifyWindow',
	'glutIdleFunc',
	'glutIgnoreKeyRepeat',
	'glutInit',
	'glutInitDisplayMode',
	'glutInitDisplayString',
	'glutInitWindowPosition',
	'glutInitWindowSize',
	'glutJoystickFunc',
	'glutKeyboardFunc',
	'glutKeyboardUpFunc',
	'glutLayerGet',
	'glutLeaveGameMode',
	'glutMainLoop',
	'glutMenuStateFunc',
	'glutMenuStatusFunc',
	'glutMotionFunc',
	'glutMouseFunc',
	'glutOverlayDisplayFunc',
	'glutPassiveMotionFunc',
	'glutPopWindow',
	'glutPositionWindow',
	'glutPostOverlayRedisplay',
	'glutPostRedisplay',
	'glutPostWindowOverlayRedisplay',
	'glutPostWindowRedisplay',
	'glutPushWindow',
	'glutRemoveMenuItem',
	'glutRemoveOverlay',
	'glutReportErrors',
	'glutReshapeFunc',
	'glutReshapeWindow',
	'glutSetColor',
	'glutSetCursor',
	'glutSetIconTitle',
	'glutSetKeyRepeat',
	'glutSetMenu',
	'glutSetWindow',
	'glutSetWindowTitle',
	'glutSetupVideoResizing',
	'glutShowOverlay',
	'glutShowWindow',
	'glutSolidCone',
	'glutSolidCube',
	'glutSolidDodecahedron',
	'glutSolidIcosahedron',
	'glutSolidOctahedron',
	'glutSolidSphere',
	'glutSolidTeapot',
	'glutSolidTetrahedron',
	'glutSolidTorus',
	'glutSpaceballButtonFunc',
	'glutSpaceballMotionFunc',
	'glutSpaceballRotateFunc',
	'glutSpecialFunc',
	'glutSpecialUpFunc',
	'glutStopVideoResizing',
	'glutStrokeCharacter',
	'glutStrokeLength',
	'glutStrokeWidth',
	'glutSwapBuffers',
	'glutTabletButtonFunc',
	'glutTabletMotionFunc',
	'glutTimerFunc',
	'glutUseLayer',
	'glutVideoPan',
	'glutVideoResize',
	'glutVideoResizeGet',
	'glutVisibilityFunc',
	'glutWarpPointer',
	'glutWindowStatusFunc',
	'glutWireCone',
	'glutWireCube',
	'glutWireDodecahedron',
	'glutWireIcosahedron',
	'glutWireOctahedron',
	'glutWireSphere',
	'glutWireTeapot',
	'glutWireTetrahedron',
	'glutWireTorus'
]

