'''OpenGL extension EXT.timer_query

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/timer_query.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_timer_query'
GL_TIME_ELAPSED_EXT = constant.Constant( 'GL_TIME_ELAPSED_EXT', 0x88BF )
glGetQueryObjecti64vEXT = platform.createExtensionFunction( 
	'glGetQueryObjecti64vEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, ctypes.POINTER(constants.GLint64EXT),),
	doc = 'glGetQueryObjecti64vEXT( GLuint(id), GLenum(pname), POINTER(constants.GLint64EXT)(params) ) -> None',
	argNames = ('id', 'pname', 'params',),
)

glGetQueryObjectui64vEXT = platform.createExtensionFunction( 
	'glGetQueryObjectui64vEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, ctypes.POINTER(constants.GLuint64EXT),),
	doc = 'glGetQueryObjectui64vEXT( GLuint(id), GLenum(pname), POINTER(constants.GLuint64EXT)(params) ) -> None',
	argNames = ('id', 'pname', 'params',),
)


def glInitTimerQueryEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
