'''OpenGL extension EXT.rescale_normal

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.rescale_normal to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.rescale_normal import *
### END AUTOGENERATED SECTION