'''OpenGL extension ARB.occlusion_query

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.occlusion_query to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.occlusion_query import *
### END AUTOGENERATED SECTION
from OpenGL.GL import glget
from OpenGL import converters
for func in ('glGenQueriesARB','glDeleteQueriesARB'):
	globals()[func] = wrapper.wrapper( 
		globals()[func],
	).setPyConverter('n').setCConverter(
		'n', arrays.AsArrayTypedSize( 'ids', arrays.GLuintArray ),
	).setCConverter(
		'ids', arrays.asArrayType(arrays.GLuintArray),
	).setReturnValues(
		wrapper.returnPyArgument( 'ids' )
	)

for func in (
	'glGetQueryivARB','glGetQueryObjectivARB','glGetQueryObjectuivARB',
):
	globals()[func] = wrapper.wrapper(globals()[func]).setOutput(
		"params", (1,)
	)
del func, glget
