'''OpenGL extension ARB.shading_language_100

Overview (from the spec)
	
	    This extension string indicates that the OpenGL Shading Language is
	    supported. The Shading Language is defined by a separate specification
	    document which can be downloaded from
	
		http://www.opengl.org/documentation/oglsl.html

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/shading_language_100.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_shading_language_100'
GL_SHADING_LANGUAGE_VERSION_ARB = constant.Constant( 'GL_SHADING_LANGUAGE_VERSION_ARB', 0x8B8C )


def glInitShadingLanguage100ARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
