'''OpenGL extension NV.present_video

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/present_video.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_present_video'
GL_FRAME_NV = constant.Constant( 'GL_FRAME_NV', 0x8E26 )
GL_FIELDS_NV = constant.Constant( 'GL_FIELDS_NV', 0x8E27 )
GL_CURRENT_TIME_NV = constant.Constant( 'GL_CURRENT_TIME_NV', 0x8E28 )
GL_NUM_FILL_STREAMS_NV = constant.Constant( 'GL_NUM_FILL_STREAMS_NV', 0x8E29 )
GL_PRESENT_TIME_NV = constant.Constant( 'GL_PRESENT_TIME_NV', 0x8E2A )
GL_PRESENT_DURATION_NV = constant.Constant( 'GL_PRESENT_DURATION_NV', 0x8E2B )


def glInitPresentVideoNV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
