'''OpenGL extension ARB.texture_env_crossbar

Overview (from the spec)
	
	This extension adds the capability to use the texture color from
	other texture units as sources to the COMBINE_ARB enviornment
	function. The ARB_texture_env_combine extension defined texture 
	enviornment functions which could use the color from the 
	current texture unit as a source. This extension adds
	the ability to use the color from any texture unit as a source.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_env_crossbar.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_env_crossbar'



def glInitTextureEnvCrossbarARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
