'''OpenGL extension EXT.pixel_transform_color_table

Overview (from the spec)
	
	This extension defines a color table that is applied immediately
	after the pixel transformation operation.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/pixel_transform_color_table.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_pixel_transform_color_table'



def glInitPixelTransformColorTableEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
