'''OpenGL extension VERSION.GL_1_3

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/VERSION/GL_1_3.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_3'
GL_TEXTURE0 = constant.Constant( 'GL_TEXTURE0', 0x84C0 )
GL_TEXTURE1 = constant.Constant( 'GL_TEXTURE1', 0x84C1 )
GL_TEXTURE2 = constant.Constant( 'GL_TEXTURE2', 0x84C2 )
GL_TEXTURE3 = constant.Constant( 'GL_TEXTURE3', 0x84C3 )
GL_TEXTURE4 = constant.Constant( 'GL_TEXTURE4', 0x84C4 )
GL_TEXTURE5 = constant.Constant( 'GL_TEXTURE5', 0x84C5 )
GL_TEXTURE6 = constant.Constant( 'GL_TEXTURE6', 0x84C6 )
GL_TEXTURE7 = constant.Constant( 'GL_TEXTURE7', 0x84C7 )
GL_TEXTURE8 = constant.Constant( 'GL_TEXTURE8', 0x84C8 )
GL_TEXTURE9 = constant.Constant( 'GL_TEXTURE9', 0x84C9 )
GL_TEXTURE10 = constant.Constant( 'GL_TEXTURE10', 0x84CA )
GL_TEXTURE11 = constant.Constant( 'GL_TEXTURE11', 0x84CB )
GL_TEXTURE12 = constant.Constant( 'GL_TEXTURE12', 0x84CC )
GL_TEXTURE13 = constant.Constant( 'GL_TEXTURE13', 0x84CD )
GL_TEXTURE14 = constant.Constant( 'GL_TEXTURE14', 0x84CE )
GL_TEXTURE15 = constant.Constant( 'GL_TEXTURE15', 0x84CF )
GL_TEXTURE16 = constant.Constant( 'GL_TEXTURE16', 0x84D0 )
GL_TEXTURE17 = constant.Constant( 'GL_TEXTURE17', 0x84D1 )
GL_TEXTURE18 = constant.Constant( 'GL_TEXTURE18', 0x84D2 )
GL_TEXTURE19 = constant.Constant( 'GL_TEXTURE19', 0x84D3 )
GL_TEXTURE20 = constant.Constant( 'GL_TEXTURE20', 0x84D4 )
GL_TEXTURE21 = constant.Constant( 'GL_TEXTURE21', 0x84D5 )
GL_TEXTURE22 = constant.Constant( 'GL_TEXTURE22', 0x84D6 )
GL_TEXTURE23 = constant.Constant( 'GL_TEXTURE23', 0x84D7 )
GL_TEXTURE24 = constant.Constant( 'GL_TEXTURE24', 0x84D8 )
GL_TEXTURE25 = constant.Constant( 'GL_TEXTURE25', 0x84D9 )
GL_TEXTURE26 = constant.Constant( 'GL_TEXTURE26', 0x84DA )
GL_TEXTURE27 = constant.Constant( 'GL_TEXTURE27', 0x84DB )
GL_TEXTURE28 = constant.Constant( 'GL_TEXTURE28', 0x84DC )
GL_TEXTURE29 = constant.Constant( 'GL_TEXTURE29', 0x84DD )
GL_TEXTURE30 = constant.Constant( 'GL_TEXTURE30', 0x84DE )
GL_TEXTURE31 = constant.Constant( 'GL_TEXTURE31', 0x84DF )
GL_ACTIVE_TEXTURE = constant.Constant( 'GL_ACTIVE_TEXTURE', 0x84E0 )
GL_CLIENT_ACTIVE_TEXTURE = constant.Constant( 'GL_CLIENT_ACTIVE_TEXTURE', 0x84E1 )
GL_MAX_TEXTURE_UNITS = constant.Constant( 'GL_MAX_TEXTURE_UNITS', 0x84E2 )
GL_TRANSPOSE_MODELVIEW_MATRIX = constant.Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX', 0x84E3 )
GL_TRANSPOSE_PROJECTION_MATRIX = constant.Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX', 0x84E4 )
GL_TRANSPOSE_TEXTURE_MATRIX = constant.Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX', 0x84E5 )
GL_TRANSPOSE_COLOR_MATRIX = constant.Constant( 'GL_TRANSPOSE_COLOR_MATRIX', 0x84E6 )
GL_MULTISAMPLE = constant.Constant( 'GL_MULTISAMPLE', 0x809D )
GL_SAMPLE_ALPHA_TO_COVERAGE = constant.Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE', 0x809E )
GL_SAMPLE_ALPHA_TO_ONE = constant.Constant( 'GL_SAMPLE_ALPHA_TO_ONE', 0x809F )
GL_SAMPLE_COVERAGE = constant.Constant( 'GL_SAMPLE_COVERAGE', 0x80A0 )
GL_SAMPLE_BUFFERS = constant.Constant( 'GL_SAMPLE_BUFFERS', 0x80A8 )
GL_SAMPLES = constant.Constant( 'GL_SAMPLES', 0x80A9 )
GL_SAMPLE_COVERAGE_VALUE = constant.Constant( 'GL_SAMPLE_COVERAGE_VALUE', 0x80AA )
GL_SAMPLE_COVERAGE_INVERT = constant.Constant( 'GL_SAMPLE_COVERAGE_INVERT', 0x80AB )
GL_MULTISAMPLE_BIT = constant.Constant( 'GL_MULTISAMPLE_BIT', 0x20000000 )
GL_NORMAL_MAP = constant.Constant( 'GL_NORMAL_MAP', 0x8511 )
GL_REFLECTION_MAP = constant.Constant( 'GL_REFLECTION_MAP', 0x8512 )
GL_TEXTURE_CUBE_MAP = constant.Constant( 'GL_TEXTURE_CUBE_MAP', 0x8513 )
GL_TEXTURE_BINDING_CUBE_MAP = constant.Constant( 'GL_TEXTURE_BINDING_CUBE_MAP', 0x8514 )
GL_TEXTURE_CUBE_MAP_POSITIVE_X = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 0x8515 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_X = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X', 0x8516 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Y = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 0x8517 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y', 0x8518 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Z = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 0x8519 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z', 0x851A )
GL_PROXY_TEXTURE_CUBE_MAP = constant.Constant( 'GL_PROXY_TEXTURE_CUBE_MAP', 0x851B )
GL_MAX_CUBE_MAP_TEXTURE_SIZE = constant.Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 0x851C )
GL_COMPRESSED_ALPHA = constant.Constant( 'GL_COMPRESSED_ALPHA', 0x84E9 )
GL_COMPRESSED_LUMINANCE = constant.Constant( 'GL_COMPRESSED_LUMINANCE', 0x84EA )
GL_COMPRESSED_LUMINANCE_ALPHA = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA', 0x84EB )
GL_COMPRESSED_INTENSITY = constant.Constant( 'GL_COMPRESSED_INTENSITY', 0x84EC )
GL_COMPRESSED_RGB = constant.Constant( 'GL_COMPRESSED_RGB', 0x84ED )
GL_COMPRESSED_RGBA = constant.Constant( 'GL_COMPRESSED_RGBA', 0x84EE )
GL_TEXTURE_COMPRESSION_HINT = constant.Constant( 'GL_TEXTURE_COMPRESSION_HINT', 0x84EF )
GL_TEXTURE_COMPRESSED_IMAGE_SIZE = constant.Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 0x86A0 )
GL_TEXTURE_COMPRESSED = constant.Constant( 'GL_TEXTURE_COMPRESSED', 0x86A1 )
GL_NUM_COMPRESSED_TEXTURE_FORMATS = constant.Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 0x86A2 )
GL_COMPRESSED_TEXTURE_FORMATS = constant.Constant( 'GL_COMPRESSED_TEXTURE_FORMATS', 0x86A3 )
GL_CLAMP_TO_BORDER = constant.Constant( 'GL_CLAMP_TO_BORDER', 0x812D )
GL_COMBINE = constant.Constant( 'GL_COMBINE', 0x8570 )
GL_COMBINE_RGB = constant.Constant( 'GL_COMBINE_RGB', 0x8571 )
GL_COMBINE_ALPHA = constant.Constant( 'GL_COMBINE_ALPHA', 0x8572 )
GL_SOURCE0_RGB = constant.Constant( 'GL_SOURCE0_RGB', 0x8580 )
GL_SOURCE1_RGB = constant.Constant( 'GL_SOURCE1_RGB', 0x8581 )
GL_SOURCE2_RGB = constant.Constant( 'GL_SOURCE2_RGB', 0x8582 )
GL_SOURCE0_ALPHA = constant.Constant( 'GL_SOURCE0_ALPHA', 0x8588 )
GL_SOURCE1_ALPHA = constant.Constant( 'GL_SOURCE1_ALPHA', 0x8589 )
GL_SOURCE2_ALPHA = constant.Constant( 'GL_SOURCE2_ALPHA', 0x858A )
GL_OPERAND0_RGB = constant.Constant( 'GL_OPERAND0_RGB', 0x8590 )
GL_OPERAND1_RGB = constant.Constant( 'GL_OPERAND1_RGB', 0x8591 )
GL_OPERAND2_RGB = constant.Constant( 'GL_OPERAND2_RGB', 0x8592 )
GL_OPERAND0_ALPHA = constant.Constant( 'GL_OPERAND0_ALPHA', 0x8598 )
GL_OPERAND1_ALPHA = constant.Constant( 'GL_OPERAND1_ALPHA', 0x8599 )
GL_OPERAND2_ALPHA = constant.Constant( 'GL_OPERAND2_ALPHA', 0x859A )
GL_RGB_SCALE = constant.Constant( 'GL_RGB_SCALE', 0x8573 )
GL_ADD_SIGNED = constant.Constant( 'GL_ADD_SIGNED', 0x8574 )
GL_INTERPOLATE = constant.Constant( 'GL_INTERPOLATE', 0x8575 )
GL_SUBTRACT = constant.Constant( 'GL_SUBTRACT', 0x84E7 )
GL_CONSTANT = constant.Constant( 'GL_CONSTANT', 0x8576 )
GL_PRIMARY_COLOR = constant.Constant( 'GL_PRIMARY_COLOR', 0x8577 )
GL_PREVIOUS = constant.Constant( 'GL_PREVIOUS', 0x8578 )
GL_DOT3_RGB = constant.Constant( 'GL_DOT3_RGB', 0x86AE )
GL_DOT3_RGBA = constant.Constant( 'GL_DOT3_RGBA', 0x86AF )
glActiveTexture = platform.createExtensionFunction( 
	'glActiveTexture', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glActiveTexture( GLenum(texture) ) -> None',
	argNames = ('texture',),
)

glClientActiveTexture = platform.createExtensionFunction( 
	'glClientActiveTexture', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glClientActiveTexture( GLenum(texture) ) -> None',
	argNames = ('texture',),
)

glMultiTexCoord1d = platform.createExtensionFunction( 
	'glMultiTexCoord1d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble,),
	doc = 'glMultiTexCoord1d( GLenum(target), GLdouble(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1dv = platform.createExtensionFunction( 
	'glMultiTexCoord1dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord1dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1f = platform.createExtensionFunction( 
	'glMultiTexCoord1f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat,),
	doc = 'glMultiTexCoord1f( GLenum(target), GLfloat(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1fv = platform.createExtensionFunction( 
	'glMultiTexCoord1fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord1fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1i = platform.createExtensionFunction( 
	'glMultiTexCoord1i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint,),
	doc = 'glMultiTexCoord1i( GLenum(target), GLint(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1iv = platform.createExtensionFunction( 
	'glMultiTexCoord1iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord1iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1s = platform.createExtensionFunction( 
	'glMultiTexCoord1s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort,),
	doc = 'glMultiTexCoord1s( GLenum(target), GLshort(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1sv = platform.createExtensionFunction( 
	'glMultiTexCoord1sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord1sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2d = platform.createExtensionFunction( 
	'glMultiTexCoord2d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord2d( GLenum(target), GLdouble(s), GLdouble(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2dv = platform.createExtensionFunction( 
	'glMultiTexCoord2dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord2dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2f = platform.createExtensionFunction( 
	'glMultiTexCoord2f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord2f( GLenum(target), GLfloat(s), GLfloat(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2fv = platform.createExtensionFunction( 
	'glMultiTexCoord2fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord2fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2i = platform.createExtensionFunction( 
	'glMultiTexCoord2i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord2i( GLenum(target), GLint(s), GLint(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2iv = platform.createExtensionFunction( 
	'glMultiTexCoord2iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord2iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2s = platform.createExtensionFunction( 
	'glMultiTexCoord2s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord2s( GLenum(target), GLshort(s), GLshort(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2sv = platform.createExtensionFunction( 
	'glMultiTexCoord2sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord2sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3d = platform.createExtensionFunction( 
	'glMultiTexCoord3d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord3d( GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3dv = platform.createExtensionFunction( 
	'glMultiTexCoord3dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord3dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3f = platform.createExtensionFunction( 
	'glMultiTexCoord3f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord3f( GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3fv = platform.createExtensionFunction( 
	'glMultiTexCoord3fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord3fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3i = platform.createExtensionFunction( 
	'glMultiTexCoord3i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord3i( GLenum(target), GLint(s), GLint(t), GLint(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3iv = platform.createExtensionFunction( 
	'glMultiTexCoord3iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord3iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3s = platform.createExtensionFunction( 
	'glMultiTexCoord3s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord3s( GLenum(target), GLshort(s), GLshort(t), GLshort(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3sv = platform.createExtensionFunction( 
	'glMultiTexCoord3sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord3sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4d = platform.createExtensionFunction( 
	'glMultiTexCoord4d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord4d( GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r), GLdouble(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4dv = platform.createExtensionFunction( 
	'glMultiTexCoord4dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord4dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4f = platform.createExtensionFunction( 
	'glMultiTexCoord4f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord4f( GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4fv = platform.createExtensionFunction( 
	'glMultiTexCoord4fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord4fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4i = platform.createExtensionFunction( 
	'glMultiTexCoord4i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord4i( GLenum(target), GLint(s), GLint(t), GLint(r), GLint(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4iv = platform.createExtensionFunction( 
	'glMultiTexCoord4iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord4iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4s = platform.createExtensionFunction( 
	'glMultiTexCoord4s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord4s( GLenum(target), GLshort(s), GLshort(t), GLshort(r), GLshort(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4sv = platform.createExtensionFunction( 
	'glMultiTexCoord4sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord4sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glLoadTransposeMatrixf = platform.createExtensionFunction( 
	'glLoadTransposeMatrixf', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray,),
	doc = 'glLoadTransposeMatrixf( GLfloatArray(m) ) -> None',
	argNames = ('m',),
)

glLoadTransposeMatrixd = platform.createExtensionFunction( 
	'glLoadTransposeMatrixd', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLdoubleArray,),
	doc = 'glLoadTransposeMatrixd( GLdoubleArray(m) ) -> None',
	argNames = ('m',),
)

glMultTransposeMatrixf = platform.createExtensionFunction( 
	'glMultTransposeMatrixf', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray,),
	doc = 'glMultTransposeMatrixf( GLfloatArray(m) ) -> None',
	argNames = ('m',),
)

glMultTransposeMatrixd = platform.createExtensionFunction( 
	'glMultTransposeMatrixd', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLdoubleArray,),
	doc = 'glMultTransposeMatrixd( GLdoubleArray(m) ) -> None',
	argNames = ('m',),
)

glSampleCoverage = platform.createExtensionFunction( 
	'glSampleCoverage', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLclampf, constants.GLboolean,),
	doc = 'glSampleCoverage( GLclampf(value), GLboolean(invert) ) -> None',
	argNames = ('value', 'invert',),
)

glCompressedTexImage3D = platform.createExtensionFunction( 
	'glCompressedTexImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage3D( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'depth', 'border', 'imageSize', 'data',),
)

glCompressedTexImage2D = platform.createExtensionFunction( 
	'glCompressedTexImage2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage2D( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'border', 'imageSize', 'data',),
)

glCompressedTexImage1D = platform.createExtensionFunction( 
	'glCompressedTexImage1D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage1D( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'border', 'imageSize', 'data',),
)

glCompressedTexSubImage3D = platform.createExtensionFunction( 
	'glCompressedTexSubImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage3D( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'width', 'height', 'depth', 'format', 'imageSize', 'data',),
)

glCompressedTexSubImage2D = platform.createExtensionFunction( 
	'glCompressedTexSubImage2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage2D( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'width', 'height', 'format', 'imageSize', 'data',),
)

glCompressedTexSubImage1D = platform.createExtensionFunction( 
	'glCompressedTexSubImage1D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage1D( GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'width', 'format', 'imageSize', 'data',),
)

glGetCompressedTexImage = platform.createExtensionFunction( 
	'glGetCompressedTexImage', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, ctypes.c_void_p,),
	doc = 'glGetCompressedTexImage( GLenum(target), GLint(level), c_void_p(img) ) -> None',
	argNames = ('target', 'level', 'img',),
)

