# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for /usr/include/GL/freeglut_ext.h
from OpenGL import platform
from OpenGL.constants import *
from OpenGL.constant import Constant
from OpenGL.arrays.arraydatatype import *
from ctypes import *
c_void = None


GLUT_ACTION_EXIT=Constant( 'GLUT_ACTION_EXIT', 0 )
GLUT_ACTION_GLUTMAINLOOP_RETURNS=Constant( 'GLUT_ACTION_GLUTMAINLOOP_RETURNS', 1 )
GLUT_ACTION_CONTINUE_EXECUTION=Constant( 'GLUT_ACTION_CONTINUE_EXECUTION', 2 )
GLUT_CREATE_NEW_CONTEXT=Constant( 'GLUT_CREATE_NEW_CONTEXT', 0 )
GLUT_USE_CURRENT_CONTEXT=Constant( 'GLUT_USE_CURRENT_CONTEXT', 1 )
GLUT_FORCE_INDIRECT_CONTEXT=Constant( 'GLUT_FORCE_INDIRECT_CONTEXT', 0 )
GLUT_ALLOW_DIRECT_CONTEXT=Constant( 'GLUT_ALLOW_DIRECT_CONTEXT', 1 )
GLUT_TRY_DIRECT_CONTEXT=Constant( 'GLUT_TRY_DIRECT_CONTEXT', 2 )
GLUT_FORCE_DIRECT_CONTEXT=Constant( 'GLUT_FORCE_DIRECT_CONTEXT', 3 )
GLUT_ACTION_ON_WINDOW_CLOSE=Constant( 'GLUT_ACTION_ON_WINDOW_CLOSE', 505 )
GLUT_WINDOW_BORDER_WIDTH=Constant( 'GLUT_WINDOW_BORDER_WIDTH', 506 )
GLUT_WINDOW_HEADER_HEIGHT=Constant( 'GLUT_WINDOW_HEADER_HEIGHT', 507 )
GLUT_VERSION=Constant( 'GLUT_VERSION', 508 )
GLUT_RENDERING_CONTEXT=Constant( 'GLUT_RENDERING_CONTEXT', 509 )
GLUT_DIRECT_RENDERING=Constant( 'GLUT_DIRECT_RENDERING', 510 )
GLUT_AUX1=Constant( 'GLUT_AUX1', 4096 )
GLUT_AUX2=Constant( 'GLUT_AUX2', 8192 )
GLUT_AUX3=Constant( 'GLUT_AUX3', 16384 )
GLUT_AUX4=Constant( 'GLUT_AUX4', 32768 )
glutMainLoopEvent=platform.createBaseFunction(
	'glutMainLoopEvent',platform.GLUT,None,
	[],
	[],
)
glutLeaveMainLoop=platform.createBaseFunction(
	'glutLeaveMainLoop',platform.GLUT,None,
	[],
	[],
)
glutMouseWheelFunc=platform.createBaseFunction(
	'glutMouseWheelFunc',platform.GLUT,None,
	[CFUNCTYPE(None, c_int, c_int, c_int, c_int)],
	['callback'],
)
glutCloseFunc=platform.createBaseFunction(
	'glutCloseFunc',platform.GLUT,None,
	[CFUNCTYPE(None)],
	['callback'],
)
glutWMCloseFunc=platform.createBaseFunction(
	'glutWMCloseFunc',platform.GLUT,None,
	[CFUNCTYPE(None)],
	['callback'],
)
glutMenuDestroyFunc=platform.createBaseFunction(
	'glutMenuDestroyFunc',platform.GLUT,None,
	[CFUNCTYPE(None)],
	['callback'],
)
glutGetWindowData=platform.createBaseFunction(
	'glutGetWindowData',platform.GLUT,POINTER(c_void),
	[],
	[],
)
glutSetWindowData=platform.createBaseFunction(
	'glutSetWindowData',platform.GLUT,None,
	[POINTER(None)],
	['data'],
)
glutGetMenuData=platform.createBaseFunction(
	'glutGetMenuData',platform.GLUT,POINTER(c_void),
	[],
	[],
)
glutSetMenuData=platform.createBaseFunction(
	'glutSetMenuData',platform.GLUT,None,
	[POINTER(None)],
	['data'],
)
glutBitmapHeight=platform.createBaseFunction(
	'glutBitmapHeight',platform.GLUT,c_int,
	[POINTER(None)],
	['font'],
)
glutBitmapString=platform.createBaseFunction(
	'glutBitmapString',platform.GLUT,None,
	[POINTER(None),POINTER(c_ubyte)],
	['font', 'string'],
)
glutStrokeString=platform.createBaseFunction(
	'glutStrokeString',platform.GLUT,None,
	[POINTER(None),POINTER(c_ubyte)],
	['font', 'string'],
)
glutWireRhombicDodecahedron=platform.createBaseFunction(
	'glutWireRhombicDodecahedron',platform.GLUT,None,
	[],
	[],
)
glutSolidRhombicDodecahedron=platform.createBaseFunction(
	'glutSolidRhombicDodecahedron',platform.GLUT,None,
	[],
	[],
)
GLUTproc = CFUNCTYPE(None) 	# /usr/include/GL/freeglut_ext.h:127
glutGetProcAddress=platform.createBaseFunction(
	'glutGetProcAddress',platform.GLUT,GLUTproc,
	[c_char_p],
	['procName'],
)

__all__ = ['GLUT_ACTION_EXIT', 'GLUT_ACTION_GLUTMAINLOOP_RETURNS',
'GLUT_ACTION_CONTINUE_EXECUTION', 'GLUT_CREATE_NEW_CONTEXT',
'GLUT_USE_CURRENT_CONTEXT', 'GLUT_FORCE_INDIRECT_CONTEXT',
'GLUT_ALLOW_DIRECT_CONTEXT', 'GLUT_TRY_DIRECT_CONTEXT',
'GLUT_FORCE_DIRECT_CONTEXT', 'GLUT_ACTION_ON_WINDOW_CLOSE',
'GLUT_WINDOW_BORDER_WIDTH', 'GLUT_WINDOW_HEADER_HEIGHT', 'GLUT_VERSION',
'GLUT_RENDERING_CONTEXT', 'GLUT_DIRECT_RENDERING', 'GLUT_AUX1', 'GLUT_AUX2',
'GLUT_AUX3', 'GLUT_AUX4', 'glutMainLoopEvent', 'glutLeaveMainLoop',
'glutMouseWheelFunc', 'glutCloseFunc', 'glutWMCloseFunc',
'glutMenuDestroyFunc', 'glutGetWindowData', 'glutSetWindowData',
'glutGetMenuData', 'glutSetMenuData', 'glutBitmapHeight', 'glutBitmapString',
'glutStrokeString', 'glutWireRhombicDodecahedron',
'glutSolidRhombicDodecahedron', 'GLUTproc', 'glutGetProcAddress']
# END GENERATED CONTENT (do not edit above this line)


